
-- ---------------------------------------------------------------------
-- The structure of this file is:
--
-- 1. Schema definition
-- 2. Foreign key declarations
-- 3. Data insertion
--
-- Please follow it when editing this file.
-- ---------------------------------------------------------------------

-- ---------------------------------------------------------------------
-- SCHEMA DEFINITION ---------------------------------------------------
-- ---------------------------------------------------------------------

DROP DATABASE IF EXISTS psa;
CREATE DATABASE psa;
USE psa;

-- ---------------------------------------------------------------------
-- - Accounts section

-- accounts table
CREATE TABLE accounts (
	id						INT UNSIGNED AUTO_INCREMENT PRIMARY KEY
								-- ID, autogenerated
,	type					VARCHAR(32) CHARACTER SET ascii COLLATE ascii_general_ci NOT NULL DEFAULT 'plain'
								-- password type
,	password				TEXT CHARACTER SET ascii COLLATE ascii_bin
								-- password text
) ENGINE=InnoDB;

-- password secrets
CREATE TABLE password_secrets (
	secret					VARCHAR(255) CHARACTER SET ascii COLLATE ascii_general_ci PRIMARY KEY,
								-- secret key
	type					INT UNSIGNED NOT NULL,
								-- client type (IS_CLIENT, IS_DOMAIN_OWNER, IS_MAIL_USER)
	id						INT UNSIGNED NOT NULL,
								-- client ID
	created					DATETIME NOT NULL
								-- time of creation
) ENGINE=InnoDB;

-- ---------------------------------------------------------------------
-- - Clients section

-- clients table
CREATE TABLE clients (
	id						INT UNSIGNED AUTO_INCREMENT PRIMARY KEY
								-- client ID, autogenerated
,	parent_id				INT UNSIGNED DEFAULT NULL
								-- parent client ID
,	vendor_id				INT UNSIGNED
								-- vendor ID
,	`type`					ENUM('client', 'reseller', 'admin') NOT NULL DEFAULT 'client'
								-- client type
,	cr_date					DATE
								-- client creation date
,	cname					VARCHAR(255) CHARACTER SET utf8 COLLATE utf8_general_ci
								-- client company name
,	pname					VARCHAR(255) CHARACTER SET utf8 COLLATE utf8_general_ci NOT NULL
								-- client personal name
,	login					VARCHAR(255) CHARACTER SET utf8 COLLATE utf8_general_ci NOT NULL
								-- client PLESK login
,	account_id				INT UNSIGNED NOT NULL
								-- account id
,	status									BIGINT UNSIGNED NOT NULL DEFAULT 0
								-- client status bitmask
,	phone					VARCHAR(255) CHARACTER SET ascii COLLATE ascii_bin
								-- client contact phone
,	fax						VARCHAR(255) CHARACTER SET ascii COLLATE ascii_bin
								-- client contact fax
,	email					VARCHAR(255) CHARACTER SET utf8 COLLATE utf8_general_ci
								-- client contact e-mail
,	address					VARCHAR(255) CHARACTER SET utf8 COLLATE utf8_general_ci
								-- client address
,	city					VARCHAR(255) CHARACTER SET utf8 COLLATE utf8_general_ci
								-- client city
,	state					VARCHAR(255) CHARACTER SET utf8 COLLATE utf8_general_ci
								-- client state
,	pcode					VARCHAR(10) CHARACTER SET ascii COLLATE ascii_bin
								-- client postoffice code
,	country					VARCHAR(2) CHARACTER SET ascii COLLATE ascii_bin
								-- client country
,	locale					VARCHAR(17) CHARACTER SET ascii COLLATE ascii_bin NOT NULL DEFAULT 'en-US'
								-- client locale
,	limits_id				INT UNSIGNED
								-- Limits object ID
,	params_id				INT UNSIGNED
								-- Parameters object ID
,	perm_id					INT UNSIGNED
								-- Permissions object ID
,	pool_id					INT UNSIGNED
								-- Repository object ID (IP Pool)
,	logo_id					INT UNSIGNED
								-- Client's logo
,	tmpl_id					INT UNSIGNED
								-- Repository object ID (Domain Templates List)
,	sapp_pool_id			INT UNSIGNED
								-- Repository object ID (IP Pool)
,	guid					VARCHAR(36) CHARACTER SET ascii COLLATE ascii_bin NOT NULL DEFAULT '00000000-0000-0000-0000-000000000000'
								-- global uniq identifier GUID
,	external_id				VARCHAR(255) CHARACTER SET ascii COLLATE ascii_bin NOT NULL DEFAULT ''
								-- identifier of object used by external applications
,	overuse				ENUM('false', 'true') NOT NULL DEFAULT 'false'
								-- overuse flag
,							UNIQUE (login)
								-- unique index on login
,							INDEX  (parent_id)
								-- REFERENCES clients (id)
,							INDEX  (pname)
								-- unique index on pname
,							INDEX (account_id)
								-- REFERENCES accounts (id)
,							INDEX (limits_id)
								-- REFERENCES Limits (id)
,							INDEX (params_id)
								-- REFERENCES Parameters (id)
,							INDEX (perm_id)
								-- REFERENCES Permissions (id)
,							INDEX (pool_id)
								-- REFERENCES Repository (rep_id)
,							INDEX (logo_id)
								-- REFERENCES Logos (id)
,							INDEX (tmpl_id)
								-- REFERENCES Repository (rep_id)
,							INDEX (sapp_pool_id)
								-- REFERENCES Repository (rep_id)
,							INDEX (vendor_id)
								-- REFERENCES clients (id)
) ENGINE=InnoDB;

INSERT INTO clients (`type`, `login`, `cr_date`) VALUES ('admin', 'admin', now());

-- clients parameters table
CREATE TABLE cl_param (
	cl_id					INT UNSIGNED NOT NULL
								-- client id
,	param					VARCHAR(245) CHARACTER SET ascii COLLATE ascii_general_ci NOT NULL
								-- parameter name
,	val						VARCHAR(255) CHARACTER SET binary
								-- parameter value
,							PRIMARY KEY (cl_id, param)
) ENGINE=InnoDB;

--	domain level users (dom_level_usrs) table
CREATE TABLE dom_level_usrs (
	dom_id					INT UNSIGNED PRIMARY KEY
								-- domain ID
,	account_id				INT UNSIGNED
								-- account id
,	state					ENUM('false','true') NOT NULL DEFAULT 'false'
								-- domain user status from client
,	card_id					INT UNSIGNED
								-- DL user card identificator
,	perm_id					INT UNSIGNED
								-- Permissions object ID
,							INDEX (dom_id)
								-- REFERENCES domains (id)
,							INDEX (account_id)
								-- REFERENCES accounts (id)
,							INDEX (card_id)
								-- REFERENCES Cards (id)
,							INDEX (perm_id)
								-- REFERENCES Permissions (id)
) ENGINE=InnoDB;

-- ---------------------------------------------------------------------
-- - Domains section

-- domains table
CREATE TABLE domains (
	id						INT UNSIGNED AUTO_INCREMENT PRIMARY KEY
								-- domain ID, autogenerated
,	cr_date					DATE
								-- domain cretion date
,	name					VARCHAR(255) CHARACTER SET ascii COLLATE ascii_general_ci NOT NULL
								-- domain name in ASCII form
,	displayName				VARCHAR(255) CHARACTER SET utf8 COLLATE utf8_general_ci NOT NULL
								-- original domain name as was created
,	dns_zone_id				INT UNSIGNED NOT NULL
								-- DNS zone ID
,	status					BIGINT UNSIGNED NOT NULL DEFAULT 0
								-- bitmask of status
,	htype					ENUM('none','vrt_hst','std_fwd','frm_fwd') NOT NULL
								-- hosting type on domain
,	real_size				BIGINT UNSIGNED DEFAULT 0
								-- disk space occuppied
,	cl_id					INT UNSIGNED NOT NULL
								-- client ID - domain owner
,	cert_rep_id				INT UNSIGNED
								-- certificate repository ID
,	limits_id				INT UNSIGNED
								-- Limits object ID
,	params_id				INT UNSIGNED
								-- Parameters object ID
,	guid					VARCHAR(36) CHARACTER SET ascii COLLATE ascii_bin NOT NULL DEFAULT '00000000-0000-0000-0000-000000000000'
								-- global uniqe identifier GUID
,	external_id				VARCHAR(255) CHARACTER SET ascii COLLATE ascii_bin NOT NULL DEFAULT ''
								-- identifier of object used by external applications
,	overuse					ENUM('false', 'true') NOT NULL DEFAULT 'false'
								-- overuse flag
,	gl_filter				ENUM('on', 'off') NOT NULL DEFAULT 'on'
								-- greylisting control
,	vendor_id				INT UNSIGNED
								-- vendor client ID
,       webspace_id				INT UNSIGNED NOT NULL DEFAULT 0
								-- id of webspace (main domain), if NULL - the domain is webspace
,	webspace_status					BIGINT UNSIGNED NOT NULL DEFAULT 0
								-- bitmask of webspace status
,	parentDomainId			INT UNSIGNED NOT NULL DEFAULT 0
								-- id of parent domain , used for subdomains
,   permissions_id          INT UNSIGNED NOT NULL DEFAULT 0
                                -- id of Permissions object
,							UNIQUE (name)
,							INDEX (displayName)
,							INDEX (cl_id)
								-- REFERENCES clients (id)
,							INDEX (cert_rep_id)
								-- REFERENCES Repository (rep_id)
,							INDEX (limits_id)
								-- REFERENCES Limits (id)
,							INDEX (params_id)
								-- REFERENCES Parameters (id)
,							INDEX (vendor_id)
								-- REFERENCES clients (id)
,							INDEX (webspace_id)
							        -- REFERENCES domains (id)
,							INDEX (parentDomainId)
							        -- REFERENCES domains (id)
,							INDEX (permissions_id)
							        -- REFERENCES Permissions (id)
) ENGINE=InnoDB;

-- domains parameters table
CREATE TABLE dom_param (
	dom_id					INT UNSIGNED NOT NULL
								-- domain ID
,	param					VARCHAR(245) CHARACTER SET ascii COLLATE ascii_general_ci NOT NULL
								-- parameter name
,	val						VARCHAR(255) CHARACTER SET binary
								-- parameter value
,							PRIMARY KEY (dom_id, param)
) ENGINE=InnoDB;

-- subdomains table
CREATE TABLE subdomains (
	id						INT UNSIGNED AUTO_INCREMENT PRIMARY KEY
								-- wu ID
,	dom_id					INT UNSIGNED NOT NULL
								-- domain ID
,	name					VARCHAR(255) CHARACTER SET ascii COLLATE ascii_general_ci NOT NULL
								-- subdomain name
,	displayName				VARCHAR(255) CHARACTER SET utf8 COLLATE utf8_general_ci NOT NULL
								-- original subdomain name as was created
,	www_root			TEXT CHARACTER SET ascii COLLATE ascii_bin NOT NULL
								-- Path to subdomain's DocRoot
,	sys_user_id				INT UNSIGNED NOT NULL
								-- sys_user ID
,	ssi						ENUM('false','true') NOT NULL DEFAULT 'false'
								-- Server Side Includes support
,	php						ENUM('false','true') NOT NULL DEFAULT 'false'
								-- PHP support
,	cgi						ENUM('false','true') NOT NULL DEFAULT 'false'
								-- CGI support
,	perl					ENUM('false','true') NOT NULL DEFAULT 'false'
								-- PERL support
,	python					ENUM('false','true') NOT NULL DEFAULT 'false'
								-- PYTHON support
,	fastcgi					ENUM('false','true') NOT NULL DEFAULT 'false'
								-- FastCGI support
,	miva					ENUM('false','true') NOT NULL DEFAULT 'false'
								-- Miva support
,	coldfusion				ENUM('false','true') NOT NULL DEFAULT 'false'
								-- ColdFusion support
,	asp						ENUM('false','true') NOT NULL DEFAULT 'false'
								-- ASP support
,	asp_dot_net				ENUM('false','true') NOT NULL DEFAULT 'false'
								-- ASP.NET support
,	`ssl`					ENUM('false','true') NOT NULL DEFAULT 'false'
								-- SSL support
,	same_ssl				ENUM('false','true') NOT NULL DEFAULT 'true'
								-- common context for ssl & non-ssl hosting
,							UNIQUE (dom_id, name)
,							INDEX dom_id_displayName (dom_id, displayName)
,							INDEX (sys_user_id)
								-- REFERENCES sys_users (id)
,	php_handler_type			 ENUM('cgi', 'fastcgi', 'module') NOT NULL DEFAULT 'module'
								-- php over cgi mode support
,   maintenance_mode		ENUM('false', 'true') NOT NULL DEFAULT 'false'
								-- maintenance mode flag
,   certificate_id          INT UNSIGNED DEFAULT 0
                                -- SSL certificate id
) ENGINE=InnoDB;

-- domain services table
CREATE TABLE DomainServices (
	id						INT UNSIGNED AUTO_INCREMENT PRIMARY KEY
								-- domain service ID
,	dom_id					INT UNSIGNED NOT NULL
								-- domain ID
,	type					ENUM('mail', 'tomcat', 'maillists', 'web')
								-- domain service type
,	status					BIGINT UNSIGNED NOT NULL DEFAULT 0
								-- domain service status (on/off)
,	parameters_id			INT UNSIGNED
								-- domain service IP collection ID
,	ipCollectionId			INT UNSIGNED
								-- parameters object ID
,							INDEX (dom_id)
								-- REFERENCES domains (id)
,							INDEX (parameters_id)
								-- REFERENCES Parameters (id)
) ENGINE=InnoDB;

-- Web Applications table
CREATE TABLE WebApps (
	id						INT UNSIGNED AUTO_INCREMENT PRIMARY KEY
								-- webapp ID
,	name					VARCHAR(255) CHARACTER SET ascii COLLATE ascii_general_ci
								-- webapp name
,	status					INT NOT NULL DEFAULT 0
								-- webapp status (on/off)
,	domain_service_id		INT UNSIGNED NOT NULL
								-- domain service object ID
,							INDEX (domain_service_id)
								-- REFERENCES DomainServices (id)
) ENGINE=InnoDB;

-- domains disk usage information
CREATE TABLE disk_usage (
	dom_id					INT UNSIGNED PRIMARY KEY
								-- domain ID
,	httpdocs				BIGINT UNSIGNED DEFAULT 0
								-- space used by http documents
,	httpsdocs				BIGINT UNSIGNED DEFAULT 0
								-- space used by https documents
,	subdomains				BIGINT UNSIGNED DEFAULT 0
								-- space used by subdomains
,	web_users				BIGINT UNSIGNED DEFAULT 0
								-- space used by web users
,	anonftp					BIGINT UNSIGNED DEFAULT 0
								-- space used by anonymous ftp directory
,	logs					BIGINT UNSIGNED DEFAULT 0
								-- space used by domain logs directory
,	dbases					BIGINT UNSIGNED DEFAULT 0
								-- space used by domain databases
,	mailboxes				BIGINT UNSIGNED DEFAULT 0
								-- space used by domain mail boxes
,	webapps					BIGINT UNSIGNED DEFAULT 0
								-- space used by domain servlets & JSPs
,	maillists				BIGINT UNSIGNED DEFAULT 0
								-- space used by maillists
,	domaindumps				BIGINT UNSIGNED DEFAULT 0
								-- space used by domain dumps
,	configs					BIGINT UNSIGNED DEFAULT 0
								-- space used by domain configs
,	chroot					BIGINT UNSIGNED DEFAULT 0
								-- space used by chrooted enviroment
,	www_root				BIGINT UNSIGNED DEFAULT 0
								-- info-only-field with www_root space
) ENGINE=InnoDB;

-- components list for statistic page
CREATE TABLE Components (
	name					VARCHAR(255) CHARACTER SET ascii COLLATE ascii_bin PRIMARY KEY
,	version					VARCHAR(255) CHARACTER SET ascii COLLATE ascii_bin
) ENGINE=InnoDB;


-- ---------------------------------------------------------------------
-- - Domain aliases section
CREATE TABLE domainaliases (
	id					INT UNSIGNED AUTO_INCREMENT PRIMARY KEY
								-- ID
,	dom_id					INT UNSIGNED NOT NULL
								-- domain ID
,	dns_zone_id				INT UNSIGNED NOT NULL
								-- DNS zone ID
,	status					INT UNSIGNED NOT NULL DEFAULT 0
								-- domain alias status (STATUS_ACTIVE, STATUS_STATU, STATUS_WITH_PARENT)
,	name					VARCHAR(255) CHARACTER SET ascii COLLATE ascii_general_ci NOT NULL
								-- domain alias name
,	displayName				VARCHAR(255) CHARACTER SET utf8 COLLATE utf8_general_ci NOT NULL
								-- original domain alias name as was created
,	dns						ENUM('false', 'true') NOT NULL DEFAULT 'false'
								-- enable DNS zone aliasing
,	mail					ENUM('false', 'true') NOT NULL DEFAULT 'false'
								-- enable mail aliasing
,	web						ENUM('false', 'true') NOT NULL DEFAULT 'false'
								-- enable web aliasing
,	tomcat					ENUM('false', 'true') NOT NULL DEFAULT 'false'
								-- enable tomcat aliasing
,							UNIQUE (name)
,							INDEX (dom_id)
								-- REFERENCES domains (id)
,							INDEX (dns_zone_id)
								-- REFERENCES dns_zone (id)
) ENGINE=InnoDB;

-- ---------------------------------------------------------------------
-- - DNS section

-- DNS zones
CREATE TABLE dns_zone (
	id					INT UNSIGNED AUTO_INCREMENT PRIMARY KEY
								-- ID
,	name					VARCHAR(255) CHARACTER SET ascii COLLATE ascii_general_ci NOT NULL
								-- zone ascii name
,	displayName				VARCHAR(255) CHARACTER SET utf8 COLLATE utf8_general_ci NOT NULL
								-- zone display name
,	status					INT UNSIGNED NOT NULL DEFAULT 0
								-- DNS zone status (STATUS_ACTIVE, STATUS_STATUS, STATUS_WITH_PARENT)
,	syncSoa					enum('true','false','skip') NOT NULL default 'skip'
								-- DNS zone osa record synchronization status
,	syncRecords				enum('true','false','skip') NOT NULL default 'skip'
								-- DNS zone synchronization status
,	email					VARCHAR(255) CHARACTER SET utf8 COLLATE utf8_general_ci
								-- admin email
,	type					ENUM('slave','master') NOT NULL DEFAULT 'master'
								-- DNS zone type
,	ttl						INT UNSIGNED NOT NULL DEFAULT 86400
								-- SOA TTL
,	ttl_unit				INT UNSIGNED NOT NULL DEFAULT 1
								-- SOA TTL UNITS
,	refresh					INT UNSIGNED NOT NULL DEFAULT 10800
								-- SOA REFRESH
,	refresh_unit			INT UNSIGNED NOT NULL DEFAULT 1
								-- SOA REFRESH UNITS
,	retry					INT UNSIGNED NOT NULL DEFAULT 3600
								-- SOA RETRY
,	retry_unit				INT UNSIGNED NOT NULL DEFAULT 1
								-- SOA RETRY UNITS
,	expire					INT UNSIGNED NOT NULL DEFAULT 604800
								-- SOA EXPIRE
,	expire_unit				INT UNSIGNED NOT NULL DEFAULT 1
								-- SOA EXPIRE UNITS
,	minimum					INT UNSIGNED NOT NULL DEFAULT 10800
								-- SOA MINIMUM
,	minimum_unit			INT UNSIGNED NOT NULL DEFAULT 1
								-- SOA MINIMUM UNITS
,	serial_format 			enum('UNIXTIMESTAMP','YYYYMMDDNN') NOT NULL default 'UNIXTIMESTAMP'
,	serial 					VARCHAR(12) CHARACTER SET ascii COLLATE ascii_bin NOT NULL default '0'
) ENGINE=InnoDB;

-- DNS Resource Records
CREATE TABLE dns_recs (
	id					INT UNSIGNED AUTO_INCREMENT PRIMARY KEY
								-- DNS RR ID
,	dns_zone_id				INT UNSIGNED
								-- DNS zone ID
,	type					ENUM('NS','A','AAAA','CNAME','MX','PTR','TXT', 'SRV', 'master', 'none') NOT NULL DEFAULT 'A'
								-- RR type
,	displayHost				VARCHAR(255) CHARACTER SET utf8 COLLATE utf8_general_ci NOT NULL
								-- left column in zone file
,	host					VARCHAR(255) CHARACTER SET ascii COLLATE ascii_general_ci NOT NULL
								-- left column in zone file
,	displayVal				VARCHAR(255) CHARACTER SET utf8 COLLATE utf8_general_ci NOT NULL
								-- right column in zone file
,	val						VARCHAR(255) CHARACTER SET ascii COLLATE ascii_general_ci NOT NULL
								-- right column in zone file
,	opt						VARCHAR(255) CHARACTER SET ascii COLLATE ascii_general_ci NOT NULL DEFAULT ''
								-- options (preferences for MX, mask for PTR)
,	time_stamp				TIMESTAMP NOT NULL
,							INDEX (type)
,							INDEX (dns_zone_id)
								-- REFERENCES dns_zone (id)
,							INDEX (host)
) ENGINE=InnoDB;

-- DNS Resource Records
CREATE TABLE dns_refs (
  `uid`             VARCHAR(255) CHARACTER SET ascii COLLATE ascii_bin PRIMARY KEY,
                      -- reference uid
  zoneId            INT UNSIGNED NOT NULL,
                      -- reference to dns zone
  zoneRecordId      INT UNSIGNED DEFAULT NULL,
                      -- reference to dns zone record
  templateRecordId  INT UNSIGNED DEFAULT NULL,
                      -- reference to source template record
  status            enum('syn', 'mod', 'del') NOT NULL DEFAULT 'syn',
                      -- reference status
                    INDEX (`zoneId`),
                    INDEX (`zoneRecordId`),
                    INDEX (`templateRecordId`)
) ENGINE=InnoDB;

-- DNS Resource Records Template
CREATE TABLE dns_recs_t (
	id						INT UNSIGNED AUTO_INCREMENT PRIMARY KEY
								-- DNS RR ID
,	`uid`						VARCHAR(255) CHARACTER SET ascii COLLATE ascii_bin DEFAULT NULL
								-- DNS template record source uid, used to identify record on restore default template
,	type					ENUM('NS','A','AAAA','CNAME','MX','PTR','TXT', 'SRV') NOT NULL DEFAULT 'A'
								-- RR type
,	displayHost				VARCHAR(255) CHARACTER SET utf8 COLLATE utf8_general_ci NOT NULL
								-- left column in zone file
,	host					VARCHAR(255) CHARACTER SET ascii COLLATE ascii_general_ci NOT NULL
								-- left column in zone file
,	displayVal				VARCHAR(255) CHARACTER SET utf8 COLLATE utf8_general_ci NOT NULL
								-- right column in zone file
,	val					VARCHAR(255) CHARACTER SET ascii COLLATE ascii_general_ci NOT NULL
								-- right column in zone file
,	opt						VARCHAR(255) CHARACTER SET ascii COLLATE ascii_general_ci NOT NULL DEFAULT ''
								-- options (preferences for MX, mask for PTR)
,	time_stamp				TIMESTAMP NOT NULL
) ENGINE=InnoDB;

-- ---------------------------------------------------------------------
-- - Hosting section

-- physical hosting table
CREATE TABLE hosting (
	dom_id					INT UNSIGNED PRIMARY KEY
								-- domain ID
,	sys_user_id				INT UNSIGNED NOT NULL
								-- sys_user ID
,	ip_address_id			INT UNSIGNED NOT NULL
								-- hosting IP address
,	www_root			TEXT CHARACTER SET ascii COLLATE ascii_bin NOT NULL
								-- Path to domain's DocRoot
,	real_traffic			BIGINT UNSIGNED DEFAULT 0
								-- real http traffic from month start
,	fp						ENUM('false','true') NOT NULL DEFAULT 'false'
								-- FrontPage support
,	fp_ssl					ENUM('false','true') NOT NULL DEFAULT 'false'
								-- FrontPage over SSL support
,	fp_enable				ENUM('false','true') NOT NULL DEFAULT 'false'
								-- FP authorization enable/disable
,	fp_adm					VARCHAR(16) CHARACTER SET ascii COLLATE ascii_bin NOT NULL
								-- admin login for FP
,	fp_pass					VARCHAR(20) CHARACTER SET ascii COLLATE ascii_bin NOT NULL
								-- admin password for FP
,	ssi						ENUM('false','true') NOT NULL DEFAULT 'false'
								-- Server Side Includes support
,	php						ENUM('false','true') NOT NULL DEFAULT 'false'
								-- PHP support
,	cgi						ENUM('false','true') NOT NULL DEFAULT 'false'
								-- CGI support
,	perl					ENUM('false','true') NOT NULL DEFAULT 'false'
								-- PERL support
,	python					ENUM('false','true') NOT NULL DEFAULT 'false'
								-- PYTHON support
,	fastcgi					ENUM('false','true') NOT NULL DEFAULT 'false'
								-- FastCGI support
,	miva					ENUM('false','true') NOT NULL DEFAULT 'false'
								-- Miva support
,	coldfusion				ENUM('false','true') NOT NULL DEFAULT 'false'
								-- ColdFusion support
,	asp						ENUM('false','true') NOT NULL DEFAULT 'false'
								-- ASP support
,	asp_dot_net				ENUM('false','true') NOT NULL DEFAULT 'false'
								-- ASP.NET support
,	`ssl`						ENUM('false','true') NOT NULL DEFAULT 'false'
								-- SSL support
,	same_ssl				ENUM('false','true') NOT NULL DEFAULT 'true'
								-- common context for ssl & non-ssl hosting
,	webstat					ENUM('none','webalizer', 'awstats') NOT NULL DEFAULT 'none'
								-- Webstat support
,	traffic_bandwidth		INT DEFAULT -1
								-- traffic bandwidth in Bytes/sec
,	max_connection			INT DEFAULT -1
								-- max connection to this vhost
,							INDEX (ip_address_id)
								-- REFERENCES IP_Addresses (id)
,	php_handler_type			 ENUM('cgi', 'fastcgi', 'module') NOT NULL DEFAULT 'module'
								-- php over cgi mode support
,   maintenance_mode		ENUM('false', 'true') NOT NULL DEFAULT 'false'
								-- maintenance mode flag
,   certificate_id          INT UNSIGNED DEFAULT 0
                                -- SSL certificate id
) ENGINE=InnoDB;

--	webusers (wu) table (example: www.yahoo.com/~kan)
CREATE TABLE web_users (
	id						INT UNSIGNED AUTO_INCREMENT PRIMARY KEY
								-- wu ID
,	dom_id					INT UNSIGNED NOT NULL
								-- domain ID
,	sys_user_id				INT UNSIGNED NOT NULL
								-- sys_user ID
,	ssi						ENUM('false','true') NOT NULL DEFAULT 'false'
								-- Server Side Includes support
,	php						ENUM('false','true') NOT NULL DEFAULT 'false'
								-- PHP support
,	cgi						ENUM('false','true') NOT NULL DEFAULT 'false'
								-- CGI support
,	perl					ENUM('false','true') NOT NULL DEFAULT 'false'
								-- PERL support
,	python					ENUM('false','true') NOT NULL DEFAULT 'false'
								-- PYTHON support
,	fastcgi					ENUM('false','true') NOT NULL DEFAULT 'false'
								-- FastCGI support
,	asp						ENUM('false','true') NOT NULL DEFAULT 'false'
								-- ASP support
,	asp_dot_net				ENUM('false','true') NOT NULL DEFAULT 'false'
								-- ASP.NET support
,							INDEX (dom_id)
								-- REFERENCES domains (id)
,							UNIQUE (sys_user_id)
								-- REFERENCES sys_users (id)
) ENGINE=InnoDB;

--	additional ftp users table
CREATE TABLE ftp_users (
	id						INT UNSIGNED AUTO_INCREMENT PRIMARY KEY
								-- FTP user ID
,	dom_id					INT UNSIGNED NOT NULL
								-- domain ID
,	sys_user_id				INT UNSIGNED NOT NULL
								-- sys_user ID
,							INDEX (dom_id)
								-- REFERENCES domains (id)
,							UNIQUE (sys_user_id)
								-- REFERENCES sys_users (id)
) ENGINE=InnoDB;

-- password protected directories table (PPD)
CREATE TABLE protected_dirs (
	id						INT UNSIGNED AUTO_INCREMENT PRIMARY KEY
								-- PPD ID
,	non_ssl					ENUM('false','true') NOT NULL DEFAULT 'false'
								-- which tree used for PPD (www-root)
,	`ssl`						ENUM('false','true') NOT NULL DEFAULT 'false'
								-- which tree used for PPD (httpsdocs)
,	cgi_bin						ENUM('false','true') NOT NULL DEFAULT 'false'
								-- which tree used for PPD (cgi-bin)
,	realm					VARCHAR(255) CHARACTER SET utf8 COLLATE utf8_bin
								-- Header text
,	path					VARCHAR(245) CHARACTER SET ascii COLLATE ascii_bin NOT NULL
								-- directory name (path)
,	dom_id					INT UNSIGNED NOT NULL
								-- domain ID
,							UNIQUE (dom_id, path)
) ENGINE=InnoDB;

-- PPD users
CREATE TABLE pd_users (
	id						INT UNSIGNED AUTO_INCREMENT PRIMARY KEY
								-- PPD user ID
,	login					VARCHAR(20) CHARACTER SET ascii COLLATE ascii_bin NOT NULL
								-- PPD user login
,	account_id				INT UNSIGNED NOT NULL
								-- account id
,	pd_id					INT UNSIGNED NOT NULL
								-- PPD ID
,							INDEX (account_id)
								-- REFERENCES accounts (id)
,							UNIQUE (pd_id, login)
) ENGINE=InnoDB;

-- logrotation configuration
CREATE TABLE log_rotation (
	id						INT UNSIGNED AUTO_INCREMENT PRIMARY KEY
								-- log rotation record ID, autogenerated
,	period_type				ENUM('by_time','by_size') NOT NULL DEFAULT 'by_time'
								-- type of log rotation period
,	period					VARCHAR(50) CHARACTER SET ascii COLLATE ascii_bin
								-- log rotation period
,	max_number_of_logfiles	BIGINT UNSIGNED DEFAULT 0
								-- max number of logfiles
,	compress_enable			ENUM('false','true') NOT NULL DEFAULT 'false'
								-- enable or disable logfiles compression
,	email					VARCHAR(255) CHARACTER SET utf8 COLLATE utf8_general_ci
								-- email address for rotated logfile sending
,	turned_on				ENUM('false','true') NOT NULL DEFAULT 'false'
								-- enable or disable log rotation service
) ENGINE=InnoDB;

-- destination URLs for standard forwarding && frame forwarding
CREATE TABLE forwarding (
	dom_id					INT UNSIGNED PRIMARY KEY
								-- domain ID
,	ip_address_id			INT UNSIGNED NOT NULL
,	redirect				VARCHAR(255) CHARACTER SET utf8 COLLATE utf8_general_ci
								-- destination URL
,							INDEX (ip_address_id)
								-- REFERENCES IP_Addresses (id)
) ENGINE=InnoDB;

-- anonymous virtual FTP domain information
CREATE TABLE anon_ftp (
	id						INT UNSIGNED AUTO_INCREMENT PRIMARY KEY
,	dom_id					INT UNSIGNED NOT NULL
,	max_conn				INT UNSIGNED
								-- maximum connections limit
,	bandwidth				INT UNSIGNED
								-- bandwidth limit
,	incoming				ENUM('false','true') NOT NULL DEFAULT 'false'
								-- Turn incoming on or off
,	incoming_readable		ENUM('false','true') NOT NULL DEFAULT 'false'
								-- Is incoming directory readable
,	incoming_subdirs		ENUM('false','true') NOT NULL DEFAULT 'false'
								-- Enable create subdirs in incoming
,	status					ENUM('false','true') NOT NULL DEFAULT 'false'
								-- Turn anonymous virtual FTP domain on/off
,	quota					BIGINT UNSIGNED DEFAULT 1048576
								-- Incoming directory quota
,	display_login			ENUM('false','true') NOT NULL DEFAULT 'false'
								-- is display login message enable
,	login_text				TEXT CHARACTER SET utf8 COLLATE utf8_general_ci
								-- login message text
,							UNIQUE (dom_id)
								-- REFERENCES domains (id)
) ENGINE=InnoDB;

-- ---------------------------------------------------------------------
-- - Traffic section

-- daily traffic statistics for Domains
CREATE TABLE DomainsTraffic (
	dom_id					INT UNSIGNED NOT NULL
								-- domain ID
,	date					DATE NOT NULL
								-- date
,	http_in					BIGINT UNSIGNED NOT NULL DEFAULT 0
								-- http(s) input traffic in bytes for this data
,	http_out				BIGINT UNSIGNED NOT NULL DEFAULT 0
								-- http(s) output traffic in bytes for this data
,	ftp_in					BIGINT UNSIGNED NOT NULL DEFAULT 0
								-- ftp(s) input traffic in bytes for this data
,	ftp_out					BIGINT UNSIGNED NOT NULL DEFAULT 0
								-- ftp(s) output traffic in bytes for this data
,	smtp_in					BIGINT UNSIGNED NOT NULL DEFAULT 0
								-- smtp(s) input traffic in bytes for this data
,	smtp_out				BIGINT UNSIGNED NOT NULL DEFAULT 0
								-- smtp(s) output traffic in bytes for this data
,	pop3_imap_in			BIGINT UNSIGNED NOT NULL DEFAULT 0
								-- pop3(s)/imap(s) input traffic in bytes for this data
,	pop3_imap_out			BIGINT UNSIGNED NOT NULL DEFAULT 0
								-- pop3(s)/imap(s) output traffic in bytes for this data
,							PRIMARY KEY (dom_id, date)
) ENGINE=InnoDB;

-- daily traffic statistics for Clients
CREATE TABLE ClientsTraffic (
	cl_id					INT UNSIGNED NOT NULL
								-- client id
,	date					DATE NOT NULL
								-- date
,	http_in					BIGINT UNSIGNED NOT NULL DEFAULT 0
								-- http(s) input traffic in bytes for this data
,	http_out				BIGINT UNSIGNED NOT NULL DEFAULT 0
								-- http(s) output traffic in bytes for this data
,	ftp_in					BIGINT UNSIGNED NOT NULL DEFAULT 0
								-- ftp(s) input traffic in bytes for this data
,	ftp_out					BIGINT UNSIGNED NOT NULL DEFAULT 0
								-- ftp(s) output traffic in bytes for this data
,	smtp_in					BIGINT UNSIGNED NOT NULL DEFAULT 0
								-- smtp(s) input traffic in bytes for this data
,	smtp_out				BIGINT UNSIGNED NOT NULL DEFAULT 0
								-- smtp(s) output traffic in bytes for this data
,	pop3_imap_in			BIGINT UNSIGNED NOT NULL DEFAULT 0
								-- pop3(s)/imap(s) input traffic in bytes for this data
,	pop3_imap_out			BIGINT UNSIGNED NOT NULL DEFAULT 0
								-- pop3(s)/imap(s) output traffic in bytes for this data
,							PRIMARY KEY (cl_id, date)
) ENGINE=InnoDB;

-- ---------------------------------------------------------------------
-- - Certificates section

CREATE TABLE certificates (
	id						INT UNSIGNED AUTO_INCREMENT PRIMARY KEY
,	csr						BLOB NOT NULL DEFAULT ''
								-- CSR
,	pvt_key					BLOB NOT NULL DEFAULT ''
								-- Certificate private key
,	cert					BLOB NOT NULL DEFAULT ''
								-- Certificate body
,	cert_file				VARCHAR(255) CHARACTER SET ascii COLLATE ascii_bin NOT NULL DEFAULT ''
								-- Certificate file name
,	ca_cert					BLOB NOT NULL DEFAULT ''
								-- CA certificate
,	ca_file					VARCHAR(255) CHARACTER SET ascii COLLATE ascii_bin NOT NULL DEFAULT ''
								-- CA certificate file name
,	name					VARCHAR(255) CHARACTER SET utf8 COLLATE utf8_general_ci NOT NULL DEFAULT ''
								-- Certificate name
) ENGINE=InnoDB;

-- ---------------------------------------------------------------------
-- - Maiss Mail section
CREATE TABLE mass_mail (
	id						INT UNSIGNED AUTO_INCREMENT PRIMARY KEY
								-- mass mail ID
,	name					VARCHAR(255) CHARACTER SET utf8 COLLATE utf8_general_ci NOT NULL DEFAULT ''
								-- mass mail NAME
,	from_email				VARCHAR(255) CHARACTER SET utf8 COLLATE utf8_general_ci NOT NULL DEFAULT ''
								-- mass mail FROM
,	to_admin				ENUM('false', 'true') NOT NULL DEFAULT 'false'
								-- mass mail TO ADMIN
,	to_resellers			ENUM('false', 'true') NOT NULL DEFAULT 'false'
								-- mass mail TO RESELLERS
,	to_resellers_mode		ENUM('all', 'select', 'except') NOT NULL DEFAULT 'all'
								-- mass mail TO RESELLERS MODE
,	to_clients				ENUM('false', 'true') NOT NULL DEFAULT 'false'
								-- mass mail TO CLIENTS
,	to_clients_mode			ENUM('all', 'select', 'except') NOT NULL DEFAULT 'all'
								-- mass mail TO CLIENTS MODE
,	to_domains				ENUM('false', 'true') NOT NULL DEFAULT 'false'
								-- mass mail TO DOMAINS
,	to_domains_mode			ENUM('all', 'select', 'except') NOT NULL DEFAULT 'all'
								-- mass mail TO DOMAINS MODE
,	subject					VARCHAR(255) CHARACTER SET utf8 COLLATE utf8_general_ci NOT NULL
								-- mass mail SUBJECT
,	body					TEXT CHARACTER SET utf8 COLLATE utf8_general_ci NOT NULL
								-- mass mail BODY
,	cdate					DATE
								-- mass mail creation date
,							INDEX (name)
) ENGINE=InnoDB;

CREATE TABLE mass_mail_clients (
	mm_id					INT UNSIGNED NOT NULL
								-- mass mail ID
,	cl_id					INT UNSIGNED NOT NULL
								-- client ID
,							INDEX (mm_id)
								-- REFERENCES mass_mail (id)
,							INDEX (cl_id)
								-- REFERENCES clients (id)
,							UNIQUE(mm_id, cl_id)
) ENGINE=InnoDB;

CREATE TABLE mass_mail_domains (
	mm_id					INT UNSIGNED NOT NULL
								-- mass mail ID
,	dom_id					INT UNSIGNED NOT NULL
								-- domain ID
,							INDEX (mm_id)
								-- REFERENCES mass_mail (id)
,							INDEX (dom_id)
								-- REFERENCES domains (id)
,							UNIQUE(mm_id, dom_id)
) ENGINE=InnoDB;

-- ---------------------------------------------------------------------
-- - Mail section

-- mail names table (mn)
CREATE TABLE mail (
	id						INT UNSIGNED AUTO_INCREMENT PRIMARY KEY
								-- mn ID
,	userId					INT UNSIGNED NOT NULL DEFAULT 0
								-- associated user id
,	mail_name				VARCHAR(245) CHARACTER SET ascii COLLATE ascii_general_ci NOT NULL
								-- mail name
,	perm_id					INT UNSIGNED NOT NULL
								-- permissions id
,	postbox					ENUM('false','true') NOT NULL DEFAULT 'false'
								-- is postbox created ?
,	account_id				INT UNSIGNED NOT NULL
								-- account id
,	redirect				ENUM('false','true') NOT NULL DEFAULT 'false'
								-- is mail redirect created ?
,	redir_addr				VARCHAR(255) CHARACTER SET utf8 COLLATE utf8_general_ci
								-- redirect destination (e-mail address)
,	mail_group				ENUM('false','true') NOT NULL DEFAULT 'false'
								-- is mail group created ?
,	autoresponder			ENUM('false','true') NOT NULL DEFAULT 'false'
								-- is autoresponders enabled on mailname ?
,	spamfilter				ENUM('false','true') NOT NULL DEFAULT 'true'
								-- is spamfilter enabled on mailname ?
,	virusfilter				ENUM('none','incoming', 'outgoing', 'any') NOT NULL DEFAULT 'none'
								-- is virusfilter enabled on mailname ?
,	mbox_quota				BIGINT DEFAULT -1 NOT NULL
,	dom_id					INT UNSIGNED NOT NULL
								-- domain ID
,							INDEX (account_id)
								-- REFERENCES accounts (id)
,							INDEX (perm_id)
								-- REFERENCES Permissions (id)
,							UNIQUE (dom_id, mail_name)
) ENGINE=InnoDB;

-- mail alias table
CREATE TABLE mail_aliases (
	id						INT UNSIGNED AUTO_INCREMENT PRIMARY KEY
								-- ID
,	mn_id					INT UNSIGNED NOT NULL
								-- mailname ID
,	alias					VARCHAR(245) CHARACTER SET ascii COLLATE ascii_general_ci NOT NULL
								-- mail alias name
,							UNIQUE (mn_id, alias)
) ENGINE=InnoDB;

-- mail group members table (mg_mem)
CREATE TABLE mail_redir (
	id						INT UNSIGNED AUTO_INCREMENT PRIMARY KEY
								-- mg_mem ID
,	mn_id					INT UNSIGNED NOT NULL
								-- mn ID
,	address					VARCHAR(245) CHARACTER SET utf8 COLLATE utf8_general_ci NOT NULL
								-- e-mail address of mail group member
) ENGINE=InnoDB;

-- autoresponders table
CREATE TABLE mail_resp (
	id						INT UNSIGNED AUTO_INCREMENT PRIMARY KEY
								-- autoresponder ID
,	mn_id					INT UNSIGNED NOT NULL
								-- mail name ID
,	resp_name				VARCHAR(245) CHARACTER SET utf8 COLLATE utf8_general_ci NOT NULL
								-- autoresponder name
,	keystr					VARCHAR(255) CHARACTER SET utf8 COLLATE utf8_general_ci
								-- request string (ex: "send price list")
,	key_where				ENUM('subj','body','no') NOT NULL DEFAULT 'no'
								-- request place
,	subject					VARCHAR(255) CHARACTER SET utf8 COLLATE utf8_general_ci
								-- respond with this Subject:
,	reply_to				VARCHAR(255) CHARACTER SET utf8 COLLATE utf8_general_ci
								-- respond with this Reply-To:
,	content_type			VARCHAR(245) CHARACTER SET utf8 COLLATE utf8_general_ci NOT NULL DEFAULT 'text/plain'
								-- text content_type
,	charset					VARCHAR(245) CHARACTER SET ascii COLLATE ascii_bin NOT NULL DEFAULT 'UTF-8'
								-- text codepage
,	text					MEDIUMTEXT CHARACTER SET utf8 COLLATE utf8_general_ci
								-- respond with this text
,	resp_on					ENUM('false','true') NOT NULL DEFAULT 'false'
								-- is the responder on?
,	ans_freq				INT DEFAULT 10
								-- (default was 86400) responses in one day
,	mem_limit				INT DEFAULT 1000
								-- number of records in resp_freq for this responder
,							INDEX mn_id_resp_name (mn_id, resp_name)
) ENGINE=InnoDB;

-- number of responses from email	TEMP
CREATE TABLE resp_freq (
	id						INT UNSIGNED AUTO_INCREMENT PRIMARY KEY
,	rn_id					INT UNSIGNED NOT NULL
,	email					VARCHAR(245) CHARACTER SET ascii COLLATE ascii_general_ci NOT NULL
								-- requester email
,	num						INT DEFAULT 0
								-- number of requests in this day
,	time_resp				TIMESTAMP NOT NULL
,							UNIQUE (rn_id, email)
) ENGINE=InnoDB;

-- attachments files for autoresponders
CREATE TABLE resp_attach (
	id						INT UNSIGNED AUTO_INCREMENT PRIMARY KEY
								-- file ID
,	rn_id					INT UNSIGNED NOT NULL
								-- autoresponder ID
,	filename				VARCHAR(245) CHARACTER SET utf8 COLLATE utf8_general_ci NOT NULL
								-- attachment file name
,							UNIQUE (rn_id, filename)
) ENGINE=InnoDB;

-- request forwarding addresses for autoresponders
CREATE TABLE resp_forward (
	id						INT UNSIGNED AUTO_INCREMENT PRIMARY KEY
								-- ID
,	rn_id					INT UNSIGNED NOT NULL
								-- autoresponder ID
,	address					VARCHAR(245) CHARACTER SET utf8 COLLATE utf8_general_ci NOT NULL
								-- email address to redirect request
) ENGINE=InnoDB;

-- used for SMTP poplocks and IP white list for relay
CREATE TABLE smtp_poplocks (
	ip_address				VARCHAR(39) CHARACTER SET ascii COLLATE ascii_general_ci NOT NULL
								-- IP address
,							INDEX (ip_address)
,	ip_mask					INT UNSIGNED NOT NULL DEFAULT 32
								-- IP mask
,	lock_time				DATETIME
								-- lock time
) ENGINE=InnoDB;

-- mail parameters table (temporary table for skin and language save)
CREATE TABLE mn_param (
	mn_id					INT UNSIGNED NOT NULL
								-- mail name id
,	param					VARCHAR(245) CHARACTER SET ascii COLLATE ascii_general_ci NOT NULL
								-- parameter name
,	val						VARCHAR(255) CHARACTER SET binary
								-- parameter value
,							PRIMARY KEY (mn_id, param)
) ENGINE=InnoDB;

-- badmailfrom table
CREATE TABLE badmailfrom (
	id						INT UNSIGNED AUTO_INCREMENT PRIMARY KEY
								-- ID
,	domain					VARCHAR(255) CHARACTER SET utf8 COLLATE utf8_general_ci NOT NULL
								-- domain displayName
,							INDEX (domain)
) ENGINE=InnoDB;

-- ---------------------------------------------------------------------
-- - Notifications section

-- Notifications table
CREATE TABLE Notifications (
	id						INT UNSIGNED AUTO_INCREMENT PRIMARY KEY
								-- Notification ID
,	status					VARCHAR(1) CHARACTER SET ascii COLLATE ascii_bin NOT NULL
								-- Notification status (on/off)
,	send2admin				VARCHAR(1) CHARACTER SET ascii COLLATE ascii_bin NOT NULL
								-- Send notification to admin ?
,	send2reseller				VARCHAR(1) CHARACTER SET ascii COLLATE ascii_bin	NOT NULL
								-- Send notification to reseller ?
,	send2client				VARCHAR(1) CHARACTER SET ascii COLLATE ascii_bin	NOT NULL
								-- Send notification to client ?
,	send2dlu				VARCHAR(1) CHARACTER SET ascii COLLATE ascii_bin	NOT NULL
								-- Send notification to domain level user ?
,	send2email				VARCHAR(1) CHARACTER SET ascii COLLATE ascii_bin	NOT NULL
								-- Send notification to the email ?
,	email					VARCHAR(255) CHARACTER SET utf8 COLLATE utf8_general_ci NOT NULL
								-- Email address
,	subj					VARCHAR(255) CHARACTER SET utf8 COLLATE utf8_general_ci NOT NULL
								-- Notification subject field
,	note_id					INT	UNSIGNED
								-- Respected note ID
,							INDEX (note_id)
								-- REFERENCES Notes (id)
) ENGINE=InnoDB;

-- Note table
CREATE TABLE Notes (
	id						INT UNSIGNED AUTO_INCREMENT PRIMARY KEY
								-- Note ID
,	text					TEXT CHARACTER SET utf8 COLLATE utf8_general_ci NOT NULL
								-- Note text
) ENGINE=InnoDB;

-- ---------------------------------------------------------------------
-- - Sessions section

CREATE TABLE sessions (
	sess_id					VARCHAR(33) CHARACTER SET ascii COLLATE ascii_bin PRIMARY KEY
								-- cookie value
,	type					SMALLINT UNSIGNED NOT NULL
								-- session type (IS_ADMIN, IS_RESELLER, IS_CLIENT...)
,	login					VARCHAR(255) CHARACTER SET utf8 COLLATE utf8_general_ci NOT NULL
,	ip_address				VARCHAR(39) CHARACTER SET ascii COLLATE ascii_general_ci NOT NULL
								-- IP Address number in a dot notation
,	login_time				DATETIME NOT NULL
,	click_time				TIMESTAMP NOT NULL
,	modified				INT UNSIGNED
,	lifetime				INT UNSIGNED
,	data					TEXT CHARACTER SET binary
) ENGINE=InnoDB;

--	list supported interface languages
CREATE TABLE locales (
	id						VARCHAR(17) CHARACTER SET ascii COLLATE ascii_bin PRIMARY KEY
								-- lang ID (IETF RFC 1766): "en-US", "ru-RU", etc
,	active					ENUM('false', 'true') NOT NULL DEFAULT 'true'
) ENGINE=InnoDB;

-- Logos tables
CREATE TABLE Logos (
	id						INT UNSIGNED AUTO_INCREMENT PRIMARY KEY
								-- ID
,	name					VARCHAR(255) CHARACTER SET utf8 COLLATE utf8_general_ci
,	fake					VARCHAR(255) CHARACTER SET ascii COLLATE ascii_bin
,	url						VARCHAR(255) CHARACTER SET utf8 COLLATE utf8_general_ci
) ENGINE=InnoDB;

-- ---------------------------------------------------------------------
-- - Databases section

CREATE TABLE DatabaseServers (
	id						INT UNSIGNED AUTO_INCREMENT PRIMARY KEY
								-- ID, autogenerated
,	host					VARCHAR(63) CHARACTER SET utf8 COLLATE utf8_general_ci NOT NULL
								-- Host name or IP address
,	port					INT UNSIGNED
								-- TCP port number
,	type					ENUM('mysql', 'postgresql') NOT NULL
								-- Database server type
,	admin_login				VARCHAR(255) CHARACTER SET binary NOT NULL
								-- Administrator login
,	admin_password			VARCHAR(255) CHARACTER SET binary NOT NULL
								-- Administrator password
,	last_error				ENUM('no_error', 'connection_failed',
							     'permission_denied', 'other_error',
							     'credentials_not_set') NOT NULL DEFAULT 'no_error'
								-- Last error
, 	`server_version`		VARCHAR(255) CHARACTER SET binary NOT NULL
								-- database server version, cached
,							INDEX host_port (host, port)
) ENGINE=InnoDB;

CREATE TABLE data_bases (
	id						INT UNSIGNED AUTO_INCREMENT PRIMARY KEY
,	name					VARCHAR(63) CHARACTER SET ascii COLLATE ascii_bin NOT NULL
,	type					ENUM('mysql', 'postgresql', 'mssql') NOT NULL DEFAULT 'mysql'
,	dom_id					INT UNSIGNED NOT NULL
,	db_server_id			INT UNSIGNED NOT NULL
,	default_user_id			INT UNSIGNED DEFAULT NULL
,							UNIQUE (name, db_server_id)
,							INDEX (dom_id)
								-- REFERENCES domains (id)
,							INDEX (db_server_id)
								-- REFERENCES DatabaseServers (id)
) ENGINE=InnoDB;

CREATE TABLE db_users (
	id						INT UNSIGNED AUTO_INCREMENT PRIMARY KEY
,	login					VARCHAR(16) CHARACTER SET ascii COLLATE ascii_bin NOT NULL
,	account_id				INT UNSIGNED NOT NULL
,	db_id					INT UNSIGNED NOT NULL
,							UNIQUE (db_id, login)
,							INDEX (account_id)
								-- REFERENCES accounts (id)
) ENGINE=InnoDB;

-- ---------------------------------------------------------------------
-- - Objects section

-- Cards table
CREATE TABLE Cards (
	id						INT UNSIGNED AUTO_INCREMENT PRIMARY KEY
								-- ID, autogenerated
,	personalName			VARCHAR(255) CHARACTER SET utf8 COLLATE utf8_general_ci NOT NULL
								-- personal name
,	companyName				VARCHAR(255) CHARACTER SET utf8 COLLATE utf8_general_ci
								-- company name
,	phone					VARCHAR(255) CHARACTER SET ascii COLLATE ascii_general_ci
								-- contact phone
,	fax						VARCHAR(255) CHARACTER SET ascii COLLATE ascii_general_ci
								-- contact fax
,	email					VARCHAR(255) CHARACTER SET utf8 COLLATE utf8_general_ci
								-- contact e-mail
,	address					VARCHAR(255) CHARACTER SET utf8 COLLATE utf8_general_ci
								-- address
,	city					VARCHAR(255) CHARACTER SET utf8 COLLATE utf8_general_ci
								-- city
,	state					VARCHAR(255) CHARACTER SET utf8 COLLATE utf8_general_ci
								-- state
,	zip						VARCHAR(10) CHARACTER SET ascii COLLATE ascii_bin
								-- postoffice code
,	country					VARCHAR(2) CHARACTER SET ascii COLLATE ascii_bin
								-- country
) ENGINE=InnoDB;

-- System users
CREATE TABLE sys_users (
	id						INT UNSIGNED AUTO_INCREMENT PRIMARY KEY
								-- sys_user ID, autogenerated
,	serviceNodeId			INT UNSIGNED NOT NULL DEFAULT 0
								-- service node, where system user was created
,	login					VARCHAR(20) CHARACTER SET ascii COLLATE ascii_general_ci NOT NULL
								-- system user login
,	account_id				INT UNSIGNED NOT NULL
								-- account id
,	mapped_to				INT UNSIGNED
								-- parent system user id
,	home					VARCHAR(255) CHARACTER SET ascii COLLATE ascii_bin NOT NULL
								-- system user home directory
,	shell					VARCHAR(255) CHARACTER SET ascii COLLATE ascii_bin NOT NULL
								-- system user shell
,	quota					BIGINT UNSIGNED NOT NULL DEFAULT 0
								-- disk space hard limitation(MBytes)
,							UNIQUE (serviceNodeId, login)
								-- unique index on login for the same serviceNode
,							INDEX (account_id)
								-- REFERENCES accounts (id)
,							INDEX (mapped_to)
								-- REFERENCES sys_users (id)
) ENGINE=InnoDB;

-- permissions table
CREATE TABLE Permissions (
	id						INT UNSIGNED AUTO_INCREMENT NOT NULL
,	permission				VARCHAR(245) CHARACTER SET ascii COLLATE ascii_general_ci NOT NULL
,	value					VARCHAR(255) CHARACTER SET binary
,							PRIMARY KEY (id, permission)
) ENGINE=InnoDB;

-- parameters table
CREATE TABLE Parameters (
	id						INT UNSIGNED AUTO_INCREMENT NOT NULL
,	parameter				VARCHAR(245) CHARACTER SET ascii COLLATE ascii_general_ci NOT NULL
,	value					VARCHAR(255) CHARACTER SET binary
,							PRIMARY KEY (id, parameter)
) ENGINE=InnoDB;

-- limits table
CREATE TABLE Limits (
	id						INT UNSIGNED AUTO_INCREMENT NOT NULL
,	limit_name				VARCHAR(245) CHARACTER SET ascii COLLATE ascii_general_ci NOT NULL
,	value					VARCHAR(255) CHARACTER SET binary
,							PRIMARY KEY (id, limit_name)
) ENGINE=InnoDB;

-- template table
CREATE TABLE Templates (
	id						INT UNSIGNED AUTO_INCREMENT PRIMARY KEY
								-- tmpl ID, autogenerated
,	name					VARCHAR(255) CHARACTER SET utf8 COLLATE utf8_general_ci NOT NULL
,	note_id					INT	UNSIGNED
								-- Respected note ID
,	owner_id				INT UNSIGNED NOT NULL
								-- admin/reseller/client ID
,	type					ENUM('reseller', 'client', 'domain', 'domain_addon') NOT NULL
								-- plan type
,	uuid					VARCHAR(36) CHARACTER SET ascii COLLATE ascii_general_ci NOT NULL
								-- plan's UUID
,	external_id				VARCHAR(255) CHARACTER SET ascii COLLATE ascii_bin NOT NULL DEFAULT ''
								-- identifier of object used by external applications
,							INDEX (note_id)
								-- REFERENCES Notes (id)
,							INDEX (owner_id)
								-- REFERENCES clients (id)
,							UNIQUE (uuid)
) ENGINE=InnoDB;

-- template data table
CREATE TABLE TmplData (
	tmpl_id					INT UNSIGNED NOT NULL
,	element					VARCHAR(245) CHARACTER SET ascii COLLATE ascii_general_ci NOT NULL
,	value					VARCHAR(255) CHARACTER SET binary NOT NULL
,							PRIMARY KEY (tmpl_id, element)
) ENGINE=InnoDB;

-- Identifiers repository
CREATE TABLE Repository (
	rep_id					INT UNSIGNED AUTO_INCREMENT NOT NULL
,	component_id			INT UNSIGNED NOT NULL
,							PRIMARY KEY (rep_id, component_id)
) ENGINE=InnoDB;

-- skins table
CREATE TABLE Skins (
	id						INT UNSIGNED AUTO_INCREMENT PRIMARY KEY
								-- skin ID, autogenerated
,	name					VARCHAR(255) CHARACTER SET utf8 COLLATE utf8_general_ci NOT NULL
								-- name of skin
,	place					VARCHAR(255) CHARACTER SET ascii COLLATE ascii_bin NOT NULL
								-- skin directory
,							INDEX (name)
,							INDEX (place)
) ENGINE=InnoDB;

-- ---------------------------------------------------------------------
-- - Subscription plans section

CREATE TABLE Subscriptions (
	id					INT UNSIGNED AUTO_INCREMENT PRIMARY KEY
								-- Subscription plans ID, autogenerated
,	object_id				INT UNSIGNED NOT NULL
								-- Subscription object ID
,	object_type				ENUM('client', 'domain') NOT NULL
								-- Subscription object type
,	locked					ENUM('true', 'false') NOT NULL DEFAULT 'false'
								-- is Subscription locked for sync with plans
,	synchronized				ENUM('true', 'false') NOT NULL DEFAULT 'true'
								-- is Subscription syncronized with plans
,	custom					ENUM('true', 'false') NOT NULL DEFAULT 'false'
								-- is it custom subscription or not
,	uuid					VARCHAR(36) CHARACTER SET ascii COLLATE ascii_general_ci NOT NULL
,							UNIQUE (object_id, object_type)
								-- REFERENCES clients (id) or domains (id)
,                           UNIQUE (uuid)
) ENGINE=InnoDB;

CREATE TABLE PlansSubscriptions (
	subscription_id				INT UNSIGNED NOT NULL
								-- Subscription plans ID
,	plan_id					INT UNSIGNED NOT NULL
								-- plan (template) ID
,	quantity				INT UNSIGNED NOT NULL DEFAULT 1
								-- amount of times subscription includes plan
,							PRIMARY KEY (subscription_id, plan_id)
) ENGINE=InnoDB;

CREATE TABLE SubscriptionProperties (
    subscription_id            INT UNSIGNED NOT NULL
,   name                       VARCHAR(255) CHARACTER SET utf8 COLLATE utf8_general_ci NOT NULL
,   value                      VARCHAR(255) CHARACTER SET utf8 COLLATE utf8_general_ci NOT NULL
,	PRIMARY KEY (subscription_id, name)
) ENGINE=InnoDB;


CREATE TABLE PlanItems (
    id                       INT UNSIGNED AUTO_INCREMENT PRIMARY KEY
,   classname                VARCHAR(255) CHARACTER SET ascii COLLATE ascii_general_ci NOT NULL
,   name                     VARCHAR(255) CHARACTER SET ascii COLLATE ascii_general_ci NOT NULL
,   isVisible                INT UNSIGNED DEFAULT 1
,   applicableToSubscription INT UNSIGNED DEFAULT 0
,   applicableToEmail        INT UNSIGNED DEFAULT 0
,   applicableToSite         INT UNSIGNED DEFAULT 0
,	uuid                     VARCHAR(36) CHARACTER SET ascii COLLATE ascii_general_ci NOT NULL
,   UNIQUE (name)
,   UNIQUE (uuid)
) ENGINE=InnoDB;

CREATE TABLE PlanItemProperties (
    plan_item_id             INT UNSIGNED NOT NULL
,   name                     VARCHAR(255) CHARACTER SET utf8 COLLATE utf8_general_ci NOT NULL
,   value                    VARCHAR(255) CHARACTER SET utf8 COLLATE utf8_general_ci NOT NULL
,	PRIMARY KEY (plan_item_id, name)
) ENGINE=InnoDB;

-- ---------------------------------------------------------------------
-- - Miscellaneous section

-- miscellaneous parameters (see end of this script)
CREATE TABLE misc (
	param					VARCHAR(255) CHARACTER SET ascii COLLATE ascii_bin NOT NULL PRIMARY KEY
								-- parameter name
,	val						VARCHAR(255) CHARACTER SET binary NOT NULL
								-- parameter value
) ENGINE=InnoDB;

-- Custom buttons
CREATE TABLE custom_buttons (
	id						INT UNSIGNED AUTO_INCREMENT PRIMARY KEY
,	sort_key				INT UNSIGNED NOT NULL DEFAULT 100
								-- sort key
,	level					INT UNSIGNED NOT NULL DEFAULT 0
								-- level
,	level_id				INT UNSIGNED NOT NULL DEFAULT 0
								-- level id
,	place					ENUM('domain', 'client', 'reseller', 'admin', 'navigation') NOT NULL DEFAULT 'domain'
,	text					VARCHAR(255) CHARACTER SET utf8 COLLATE utf8_general_ci NOT NULL
,	url						VARCHAR(255) CHARACTER SET utf8 COLLATE utf8_general_ci
,	conhelp					TEXT CHARACTER SET utf8 COLLATE utf8_general_ci
,	options					INT UNSIGNED NOT NULL DEFAULT 0
,	file					VARCHAR(245) CHARACTER SET ascii COLLATE ascii_bin NOT NULL
								-- image file name
,	plan_item_name				VARCHAR(255) CHARACTER SET ascii COLLATE ascii_general_ci
) ENGINE=InnoDB;

-- Control visibility customizations
CREATE TABLE itmpl (
	id						INT UNSIGNED AUTO_INCREMENT PRIMARY KEY
								-- ID, autogenerated
,	name					VARCHAR(255) CHARACTER SET utf8 COLLATE utf8_general_ci
								-- template name
) ENGINE=InnoDB;

CREATE TABLE itmpl_data (
	itmpl_id					INT UNSIGNED NOT NULL
								-- interface template id
,	page					VARCHAR(127) CHARACTER SET ascii COLLATE ascii_bin NOT NULL
								-- page on which the control is
,	control					VARCHAR(127) CHARACTER SET ascii COLLATE ascii_bin NOT NULL
								-- control ID
,	state					ENUM('hide', 'adminOnly', 'show') NOT NULL DEFAULT 'hide'
								-- custom visibility
,	control_type			ENUM('button', 'formControl') NOT NULL DEFAULT 'button'
								-- type of control
,							PRIMARY KEY (itmpl_id, page, control)
) ENGINE=InnoDB;

-- PSA Upgrade history
CREATE TABLE upgrade_history (
	upgrade_date			DATETIME PRIMARY KEY
,	version_info			VARCHAR(50) CHARACTER SET ascii COLLATE ascii_bin NOT NULL
,	db_version				VARCHAR(50) CHARACTER SET ascii COLLATE ascii_bin NOT NULL
) ENGINE=InnoDB;

-- Server IP addresses
CREATE TABLE IP_Addresses (
	id						INT UNSIGNED AUTO_INCREMENT PRIMARY KEY
								-- IP Address ID
,	serviceNodeId			INT UNSIGNED NOT NULL DEFAULT 1
								-- Service node ID
								-- default assign to local service node with id 1
,	ip_address				VARCHAR(39) CHARACTER SET ascii COLLATE ascii_general_ci NOT NULL
								-- IP Address number in a dot notation
,	mask					VARCHAR(15) CHARACTER SET ascii COLLATE ascii_general_ci NOT NULL DEFAULT '255.255.255.0'
,	iface					VARCHAR(255) CHARACTER SET ascii COLLATE ascii_bin NOT NULL
								-- IP Address type: shared or exclusive
,	ssl_certificate_id		INT UNSIGNED NOT NULL
								-- SSL Certificate ID
,	default_domain_id		INT UNSIGNED
								-- default hosting ID (really dom_id)
,	ftps 					enum('false','true') NOT NULL DEFAULT 'false'
								-- enable ftp over SSL
,	main 					enum('false','true') NOT NULL DEFAULT 'false'
,	status					BIGINT UNSIGNED NOT NULL DEFAULT 0
,							UNIQUE (ip_address)
,							INDEX (ssl_certificate_id)
								-- REFERENCES certificates (id)
,							INDEX (default_domain_id)
								-- REFERENCES hosting (dom_id) ON DELETE SET NULL
) ENGINE=InnoDB;

-- ---------------------------------------------------------------------
-- - Action Log section

-- List of logable actions: name (for php), descr (human-readable), enabled (bool)
CREATE TABLE actions (
	id						INT UNSIGNED AUTO_INCREMENT PRIMARY KEY
								-- Action ID
,	name					VARCHAR(255) CHARACTER SET ascii COLLATE ascii_general_ci NOT NULL
								-- Action Name
,	descr					VARCHAR(255) CHARACTER SET utf8 COLLATE utf8_general_ci NOT NULL
								-- Action Description
,	enabled					ENUM ('false', 'true') NOT NULL DEFAULT 'true'
								-- Status: enabled/disabled
,							UNIQUE (name)
) ENGINE=InnoDB;

-- Action Log Content (Action)
CREATE TABLE log_actions (
	id						INT UNSIGNED AUTO_INCREMENT PRIMARY KEY
								-- Action ID
,	date					DATETIME NOT NULL
								-- Action date
,	ip_address				VARCHAR(39) CHARACTER SET ascii COLLATE ascii_general_ci NOT NULL
								-- IP from which was established connection
,	user					VARCHAR(255) CHARACTER SET utf8 COLLATE utf8_general_ci NOT NULL
								-- Control Panel user login name
,	action_id				INT UNSIGNED NOT NULL
								-- Action ID
,	object_id				INT UNSIGNED NOT NULL
								-- Identifies operated object (interaction with BS)
,							INDEX (action_id)
								-- REFERENCES actions (id)
) ENGINE=InnoDB;

-- Action Log Content (Components)
CREATE TABLE log_components (
	action_id				INT UNSIGNED NOT NULL
								-- Action ID
,	component				VARCHAR(245) CHARACTER SET ascii COLLATE ascii_general_ci NOT NULL
								-- Component
,	old_value				VARCHAR(255) CHARACTER SET binary NOT NULL
								-- Old value
,	new_value				VARCHAR(255) CHARACTER SET binary NOT NULL
								-- New value
,							PRIMARY KEY (action_id, component)
) ENGINE=InnoDB;

-- event handlers table
CREATE TABLE event_handlers (
	id						INT UNSIGNED AUTO_INCREMENT PRIMARY KEY
								-- event handler ID
,	action_id				INT UNSIGNED NOT NULL
								-- action ID
,	priority				INT UNSIGNED NOT NULL DEFAULT 0
,	user					VARCHAR(255) CHARACTER SET utf8 COLLATE utf8_general_ci NOT NULL DEFAULT 'nobody'
								-- system user name
,	command					TEXT CHARACTER SET utf8 COLLATE utf8_bin NOT NULL
								-- command string with parameters
,							INDEX (action_id)
								-- REFERENCES actions (id)
) ENGINE=InnoDB;

-- ---------------------------------------------------------------------
-- - Mail lists section

-- mail lists table
CREATE TABLE MailLists (
	id						INT UNSIGNED AUTO_INCREMENT PRIMARY KEY
								-- MailList ID, autogenerated
,	dom_id					INT UNSIGNED NOT NULL
								-- Domain ID, reference to domain id
,	name					VARCHAR(255) CHARACTER SET ascii COLLATE ascii_general_ci NOT NULL
								-- MailList name
,	status					BIGINT UNSIGNED NOT NULL DEFAULT 0
								-- MailList status bitmask
,							INDEX (dom_id)
								-- REFERENCES domains (id)
) ENGINE=InnoDB;

-- ---------------------------------------------------------------------
-- - IP Access restriction section

-- IP access restriction table
CREATE TABLE cp_access (
	id						INT UNSIGNED AUTO_INCREMENT PRIMARY KEY
								-- IP Access record id, autogenerated
,	type					ENUM('allow', 'deny') NOT NULL DEFAULT 'allow'
								-- cp acces table type
,	netaddr					VARCHAR(39) CHARACTER SET ascii COLLATE ascii_general_ci NOT NULL
								-- IP Address
,	netmask					VARCHAR(15) CHARACTER SET ascii COLLATE ascii_general_ci NOT NULL
								-- IP Netmask
) ENGINE=InnoDB;

-- ---------------------------------------------------------------------
-- - Reports section

CREATE TABLE report (
	id						INT UNSIGNED AUTO_INCREMENT PRIMARY KEY
,	type					INT UNSIGNED NOT NULL
								-- IS_CLIENT or IS_DOMAIN_OWNER
,	user_id					INT UNSIGNED NOT NULL DEFAULT 0
,	user_type				INT UNSIGNED NOT NULL
								-- IS_ADMIN or IS_CLIENT or IS_DOMAIN_OWNER
,	name					VARCHAR(255) CHARACTER SET utf8 COLLATE utf8_general_ci NOT NULL
,	is_default				ENUM('false','true') NOT NULL DEFAULT 'false'
) ENGINE=InnoDB;

CREATE TABLE report_section (
	id						INT UNSIGNED AUTO_INCREMENT PRIMARY KEY
,	report_id				INT UNSIGNED NOT NULL
,	name					VARCHAR(255) CHARACTER SET ascii COLLATE ascii_general_ci NOT NULL
,	type					ENUM('none','summary','full') NOT NULL DEFAULT 'summary'
,							INDEX (report_id)
								-- REFERENCES report (id)
) ENGINE=InnoDB;

CREATE TABLE report_auto (
	id						INT UNSIGNED AUTO_INCREMENT PRIMARY KEY
,	report_id				INT UNSIGNED NOT NULL
,	auto					INT UNSIGNED NOT NULL DEFAULT 0
,	last					DATETIME DEFAULT NULL
,	recipient				INT UNSIGNED NOT NULL DEFAULT 0
,	email					VARCHAR(254) CHARACTER SET utf8 COLLATE utf8_general_ci NOT NULL
,	client					INT UNSIGNED
,	domain					INT UNSIGNED
,							INDEX (report_id)
								-- REFERENCES report (id)
,							INDEX (client)
								-- REFERENCES clients (id)
,							INDEX (domain)
								-- REFERENCES domains (id)
) ENGINE=InnoDB;

-- ---------------------------------------------------------------------
-- - Extensions (Modules) section

-- modules table
CREATE TABLE Modules (
	id						INT UNSIGNED AUTO_INCREMENT PRIMARY KEY
								-- ID, autogenerated
,	name					VARCHAR(255) CHARACTER SET ascii COLLATE ascii_bin NOT NULL
								-- module name
,	packname				VARCHAR(255) CHARACTER SET ascii COLLATE ascii_bin NOT NULL
								-- package name (probably the same as name)
,	display_name			VARCHAR(255) CHARACTER SET utf8 COLLATE utf8_general_ci NOT NULL
								-- is display module name
,	version					VARCHAR(30) CHARACTER SET ascii COLLATE ascii_bin NOT NULL
								-- version
,	`release`					INT UNSIGNED NOT NULL
								-- release
,	description				VARCHAR(255) CHARACTER SET utf8 COLLATE utf8_general_ci
,	icon					VARCHAR(255) CHARACTER SET ascii COLLATE ascii_bin NOT NULL
,							UNIQUE (name)
) ENGINE=InnoDB;

-- ---------------------------------------------------------------------
-- - Site applications section
CREATE TABLE `APSLicenses` (
	`id` 					INT UNSIGNED AUTO_INCREMENT PRIMARY KEY
								-- License ID
,	`key_number` 			VARCHAR(255) CHARACTER SET ascii COLLATE ascii_bin NOT NULL
								-- License key number
,	`source` 				TEXT CHARACTER SET utf8 COLLATE utf8_general_ci NOT NULL
								-- License source text
,	`ka_url` 				VARCHAR(255) CHARACTER SET ascii COLLATE ascii_bin NOT NULL
								-- KA provider URL
,	`expiration_date` 		date default NULL
								-- License expiration date
,	`update_date` 			date default NULL
								-- License update date
,	`license_type_id` 		INT UNSIGNED NOT NULL
								-- License type id
,	`personal` 				ENUM ('false', 'true') NOT NULL DEFAULT 'false'
								-- is license personal (owned by domain user)
,							UNIQUE (`key_number`)
) ENGINE=InnoDB;

CREATE TABLE `APSApplicationItems` (
	`id` 					INT UNSIGNED AUTO_INCREMENT PRIMARY KEY
								-- Application Item ID
,	`license_type_id` 		INT UNSIGNED NOT NULL
								-- License type id
,	`pkg_id` 				INT UNSIGNED NOT NULL DEFAULT 0
								-- Site Aplication Package associated with
								-- this Application Item
,	`disabled`				ENUM ('false', 'true') NOT NULL DEFAULT 'false'
								-- is the application item disabled
,							INDEX (`pkg_id`)
								-- REFERENCES SiteAppPackages(id)
,							UNIQUE (`license_type_id`, `pkg_id`)
) ENGINE=InnoDB;

CREATE TABLE `APSClientApplicationItems` (
	`id` 					INT UNSIGNED AUTO_INCREMENT PRIMARY KEY
								-- Client Application Item ID
,	`client_id` 			INT UNSIGNED NOT NULL DEFAULT 0
								-- Client ID
,	`app_item_id` 			INT UNSIGNED NOT NULL DEFAULT 0
								-- Application Item associated with this Client Application Item
,	`instances_limit` 		INT NOT NULL DEFAULT -1
								-- How many instances may create client using this Client Application Item
,	`broadcast` 				ENUM ('false', 'true') NOT NULL DEFAULT 'false'
								-- is application free for subclients
,							INDEX (`client_id`)
								-- REFERENCES clients(id)
,							INDEX (`app_item_id`)
								-- REFERENCES APSApplicationItems(id)
,							UNIQUE (`client_id`, `app_item_id`)
)  ENGINE=InnoDB;

CREATE TABLE `APSLicenseTypes` (
	`id` 					INT UNSIGNED AUTO_INCREMENT PRIMARY KEY
,	`application_name` 		VARCHAR(122) CHARACTER SET ascii COLLATE ascii_bin NOT NULL
								-- application name from license source
,	`application_versions` 	VARCHAR(122) CHARACTER SET ascii COLLATE ascii_bin NOT NULL
								-- supported versions by license, comma delimited list
,	`application_features` 	VARCHAR(255) CHARACTER SET ascii COLLATE ascii_bin NOT NULL
								-- supported versions by license, comma delimited list
,   `license_type_hash`     VARCHAR(255) CHARACTER SET ascii COLLATE ascii_bin NOT NULL
                                -- external license identifier
,	`description` 			VARCHAR(255) CHARACTER SET utf8 COLLATE utf8_general_ci
,                           UNIQUE (license_type_hash)
,                           UNIQUE (`application_name`, `application_versions`, `application_features`)
) ENGINE=InnoDB;


CREATE TABLE SiteAppPackages (
	id						INT UNSIGNED AUTO_INCREMENT PRIMARY KEY
								-- application id
,	name					VARCHAR(255) CHARACTER SET ascii COLLATE ascii_bin NOT NULL
								-- short name
,	version					VARCHAR(30) CHARACTER SET ascii COLLATE ascii_bin NOT NULL
								-- version
,	`release`					VARCHAR(30) CHARACTER SET ascii COLLATE ascii_bin NOT NULL
								-- release
,	categories				VARCHAR(255) CHARACTER SET utf8 COLLATE utf8_general_ci
								-- categories
,	description				VARCHAR(255) CHARACTER SET utf8 COLLATE utf8_general_ci
								-- description
,	access_level			INT UNSIGNED NOT NULL DEFAULT 0
								-- necessary access level to install application
,	integrated				ENUM('false', 'true') NOT NULL DEFAULT 'false'
								-- integrated in Plesk
,	`package_type`			INT UNSIGNED NOT NULL DEFAULT 0
								-- package type, 0 means old appvault package, 1 - new fusion apppacks
,	params_id				INT UNSIGNED
								-- object id with values of parameters
								-- that are used for installed application packages
,							UNIQUE (name, version)
) ENGINE=InnoDB;

CREATE TABLE SiteApps (
	id						INT UNSIGNED AUTO_INCREMENT PRIMARY KEY
								-- installed application id
,   `app_release`           VARCHAR(30) CHARACTER SET ascii COLLATE ascii_bin NOT NULL
                                -- installed application release
,	dom_id					INT UNSIGNED NOT NULL
								-- reference to domain, where application is installed
,	dom_type				ENUM('domain', 'subdomain') NOT NULL DEFAULT 'domain'
								-- where application is installed
,	install_prefix			VARCHAR(255) CHARACTER SET ascii COLLATE ascii_bin NOT NULL
								-- directory of application inside vhost
,	htdocs_directory		ENUM('httpdocs', 'httpsdocs') NOT NULL DEFAULT 'httpdocs'
								-- which documents tree is used for application
,	capp_item_id			INT UNSIGNED NOT NULL
								-- reference to application in client application pool
,	params_id				INT UNSIGNED
								-- object id with values of parameters
								-- that are used for installed application
,	`license_id`			INT UNSIGNED
								-- reference to APS License from pool
,							INDEX (capp_item_id)
								-- REFERENCES APSClientApplicationItems (id)
,							INDEX (params_id)
								-- REFERENCES Parameters (id)
,							INDEX (`license_id`)
								-- REFERENCES APSLicenses(id)
) ENGINE=InnoDB;

CREATE TABLE SiteAppResources (
	app_id					INT UNSIGNED NOT NULL
								-- reference to application
,	type					ENUM('database', 'dbuser', 'custom_button') NOT NULL DEFAULT 'database'
								-- name of type
,	res_id					INT UNSIGNED NOT NULL
								-- reference to resource
,	`res_param_1` 			VARCHAR(255) CHARACTER SET ascii COLLATE ascii_bin DEFAULT ''
								-- additional, context-related parameter
,							INDEX (app_id)
								-- REFERENCES SiteApps (id)
,							UNIQUE (type, res_id)
) ENGINE=InnoDB;

CREATE TABLE SiteAppFiles (
	instance_id				INT UNSIGNED NOT NULL
,	prefix					ENUM('htdocs', 'cgi-bin') NOT NULL
,	`file`					VARCHAR(255) CHARACTER SET binary NOT NULL
,		INDEX instance_id (instance_id)
) ENGINE=InnoDB;

CREATE TABLE `siteapppackages_apscategories` (
	siteapppackage_id			INT UNSIGNED NOT NULL
,	apscategory_id				INT UNSIGNED NOT NULL
,	`order`					INT UNSIGNED NOT NULL
,	INDEX (siteapppackage_id)
,	INDEX (apscategory_id)
) ENGINE=InnoDB;

CREATE TABLE `apscategories` (
	id					INT UNSIGNED AUTO_INCREMENT PRIMARY KEY
,	category_name				VARCHAR(255) CHARACTER SET utf8 COLLATE utf8_general_ci
,	parent_id				INT UNSIGNED NOT NULL
,	INDEX (parent_id)
) ENGINE=InnoDB;

CREATE TABLE APSCatalogUpdates (
	id					INT UNSIGNED AUTO_INCREMENT PRIMARY KEY
,	`package_name`				VARCHAR(255) CHARACTER SET utf8 COLLATE utf8_general_ci
,	`package_version`			VARCHAR(30) CHARACTER SET utf8 COLLATE utf8_general_ci
,	`package_release`			VARCHAR(30) CHARACTER SET utf8 COLLATE utf8_general_ci

,	`update_name`				VARCHAR(255) CHARACTER SET utf8 COLLATE utf8_general_ci
,	`update_version`			VARCHAR(30) CHARACTER SET utf8 COLLATE utf8_general_ci
,	`update_release`			VARCHAR(30) CHARACTER SET utf8 COLLATE utf8_general_ci
,	`update_vendor`				VARCHAR(255) CHARACTER SET utf8 COLLATE utf8_general_ci
,	`update_packager`			VARCHAR(255) CHARACTER SET utf8 COLLATE utf8_general_ci

,	`received`				DATETIME
,	`update_type`				ENUM('patch', 'upgrade') NOT NULL
,	`recommended`				ENUM('true', 'false') NOT NULL DEFAULT 'false'
) ENGINE=InnoDB;



-- ---------------------------------------------------------------------
-- SpamFilter section

CREATE TABLE spamfilter (
	id						INT UNSIGNED AUTO_INCREMENT PRIMARY KEY
,	username				VARCHAR(128) CHARACTER SET ascii COLLATE ascii_general_ci NOT NULL
								-- mailnames for spamfilter control ?:
								-- full mailname for mailuser (e.g. foo@bar.com),
								-- with * as local part for domain (e.g. *@bar.com),
								-- *@* for server.
,	preferences				ENUM('false','true') NOT NULL DEFAULT 'false'
								-- Are preferences active?
,							UNIQUE (username)
) ENGINE=InnoDB;

CREATE TABLE spamfilter_preferences (
	prefid					INT UNSIGNED AUTO_INCREMENT PRIMARY KEY
,	spamfilter_id			INT UNSIGNED NOT NULL
,	preference				VARCHAR(30) CHARACTER SET ascii COLLATE ascii_general_ci NOT NULL DEFAULT ''
,	value					VARCHAR(255) CHARACTER SET utf8 COLLATE utf8_general_ci NOT NULL DEFAULT ''
,							INDEX spamfilter_id (spamfilter_id, preference, value)
) ENGINE=InnoDB;

-- ---------------------------------------------------------------------
-- - Key history section

CREATE TABLE key_history (
	id						INT UNSIGNED AUTO_INCREMENT PRIMARY KEY
,	plesk_key_id			VARCHAR(63) CHARACTER SET ascii COLLATE ascii_bin
,	name					VARCHAR(255) CHARACTER SET ascii COLLATE ascii_bin
,	filename				VARCHAR(255) CHARACTER SET ascii COLLATE ascii_bin
,	register_date			TIMESTAMP not NULL
,	update_disabled			ENUM('false', 'true') NOT NULL DEFAULT 'false'
,	options					VARCHAR(255) CHARACTER SET ascii COLLATE ascii_bin
) ENGINE=InnoDB;

CREATE TABLE key_history_params (
	key_id					INT UNSIGNED NOT NULL
,	param					VARCHAR(63) CHARACTER SET ascii COLLATE ascii_general_ci NOT NULL
,	val						VARCHAR(255) CHARACTER SET binary NOT NULL
,							PRIMARY KEY (key_id, param)
) ENGINE=InnoDB;

-- ---------------------------------------------------------------------
-- - Webalizer section

-- referrers to hide
CREATE TABLE webalizer_hidden_referrer (
	id						INT UNSIGNED AUTO_INCREMENT PRIMARY KEY
								-- Record ID, autogenerated
,	dom_id					INT UNSIGNED NOT NULL
								-- Domain ID
,	referrer				VARCHAR(255) CHARACTER SET utf8 COLLATE utf8_general_ci NOT NULL
								-- Referrer value
,							INDEX (dom_id)
								-- REFERENCES domains (id)
) ENGINE=InnoDB;

-- referrer groups
CREATE TABLE webalizer_group_referrer (
	id						INT UNSIGNED AUTO_INCREMENT PRIMARY KEY
								-- Record ID, autogenerated
,	dom_id					INT UNSIGNED NOT NULL
								-- Domain ID
,	group_name				VARCHAR(255) CHARACTER SET utf8 COLLATE utf8_general_ci NOT NULL
								-- Referrer group name
,	referrer				VARCHAR(255) CHARACTER SET utf8 COLLATE utf8_general_ci NOT NULL
								-- Referrer value
,							INDEX (dom_id)
								-- REFERENCES domains (id)
) ENGINE=InnoDB;

-- ---------------------------------------------------------------------
-- - AutoInstaller section

-- ai_vendor_sources table
CREATE TABLE ai_vendor_sources (
	id						INT UNSIGNED AUTO_INCREMENT PRIMARY KEY
								-- source ID, autogenerated
,	type					ENUM('repomd','directory') NOT NULL
								-- source type
,	url						VARCHAR(255) CHARACTER SET binary NOT NULL DEFAULT ''
,	priority				INT UNSIGNED NOT NULL DEFAULT 500
								-- source priority
,	enabled					ENUM('false', 'true') NOT NULL DEFAULT 'true'
,	auth_required			ENUM('false', 'true') NOT NULL DEFAULT 'false'
,	login					VARCHAR(255) CHARACTER SET binary DEFAULT NULL
,	password				VARCHAR(255) CHARACTER SET binary DEFAULT NULL
,							UNIQUE (url)
) ENGINE=InnoDB;


-- -------------- dashboard preset
CREATE TABLE DashboardPreset (
	id						INT UNSIGNED AUTO_INCREMENT PRIMARY KEY
								-- Dashboard preset ID, autogenerated
,	name					VARCHAR(255) CHARACTER SET utf8 COLLATE utf8_general_ci DEFAULT ''
								-- Dashboard preset name
,	uri						VARCHAR(255) CHARACTER SET ascii COLLATE ascii_general_ci NOT NULL
								-- Dashboard preset root uri
,	type					ENUM('admin', 'reseller', 'client', 'domain', 'private', 'custom') NOT NULL DEFAULT 'private'
								-- Dashboard preset type
,							UNIQUE name_type (name, type)
) ENGINE=InnoDB;

-- -------------- dashboard preset element
CREATE TABLE DashboardPresetConfig (
	id						INT UNSIGNED AUTO_INCREMENT PRIMARY KEY
								-- Dashboard preset element ID, autogenerated
,	preset_id				INT UNSIGNED NOT NULL
								-- Dashboard preset id
,	ord						INT UNSIGNED NOT NULL
								-- Dashboard element order
,	uri						VARCHAR(255) CHARACTER SET ascii COLLATE ascii_general_ci NOT NULL
								-- Dashboard preset element uri
,	parent_id				INT UNSIGNED DEFAULT NULL
								-- Parent dashboard preset element ID
,	type					ENUM('none', 'button', 'custom-buttons', 'top', 'column', 'footer', 'indicator', 'left', 'right', 'section', 'shortcut', 'tab', 'tabs', 'quick-search', 'quick-search-option') NOT NULL DEFAULT 'none'
								-- Dashboard element type
,	title					VARCHAR(255) CHARACTER SET utf8 COLLATE utf8_general_ci DEFAULT NULL
								-- Dasboard element title
,	description				VARCHAR(255) CHARACTER SET utf8 COLLATE utf8_general_ci DEFAULT NULL
								-- Dashboard element description
,	enabled					ENUM('false', 'true') NOT NULL DEFAULT 'true'
								-- Dashboard element enabled
) ENGINE=InnoDB;

-- -------------- SB integration
CREATE TABLE SBSites (
	id			INT UNSIGNED AUTO_INCREMENT PRIMARY KEY
					-- ID autogenerated
, 	virtualHost_id	INT UNSIGNED NOT NULL
					-- Domain ID
,	sb_site_id		VARCHAR(255) CHARACTER SET ascii COLLATE ascii_bin
					-- SB Site ID
,	sb_siteowner_id		VARCHAR(255) CHARACTER SET ascii COLLATE ascii_bin
					-- SB Siteowner ID
,	sb_siteowner_login	VARCHAR(255) CHARACTER SET utf8 COLLATE utf8_general_ci NOT NULL
					-- Login name to SB, used for domain owner in Plesk
,				UNIQUE (virtualHost_id)
					-- REFERENCES domains (id) [VirtualHost (id) in future]
,				UNIQUE (sb_site_id)
) ENGINE=InnoDB;

CREATE TABLE SBResellers (
	id			INT UNSIGNED AUTO_INCREMENT PRIMARY KEY
					--  ID autogenerated
,	client_id		INT UNSIGNED NOT NULL
					-- client ID
,	sb_client_login		VARCHAR(255) CHARACTER SET utf8 COLLATE utf8_general_ci NOT NULL
					-- Login name to SB, used for client in Plesk
,	sb_reseller_id		VARCHAR(255) CHARACTER SET ascii COLLATE ascii_bin NOT NULL
					--  SB User ID
,				UNIQUE (client_id)
					-- REFERENCES clients (id)
,				UNIQUE (sb_client_login)
,				UNIQUE (sb_reseller_id)
) ENGINE=InnoDB;

CREATE TABLE SBConfig (
	param_name		VARCHAR(255) CHARACTER SET ascii COLLATE ascii_bin
					--  parameter name
,	param_value		VARCHAR(255) CHARACTER SET ascii COLLATE ascii_bin
					-- parameter value
,				UNIQUE (param_name)
) ENGINE=InnoDB;

-- -------------- SSO Branding
CREATE TABLE SSOBranding (
        http_request_domain 	VARCHAR(255) CHARACTER SET utf8 COLLATE utf8_general_ci PRIMARY KEY,
        idp_url 		VARCHAR(255) CHARACTER SET utf8 COLLATE utf8_general_ci NOT NULL
) ENGINE=InnoDB;

-- --------------- IP Pool
CREATE TABLE ip_pool (
		id       				INT UNSIGNED AUTO_INCREMENT NOT NULL,
		ip_address_id   		INT(10) UNSIGNED NOT NULL,
		`type` enum('shared','exclusive'),
		PRIMARY KEY (id, ip_address_id)
) ENGINE=InnoDB;

-- -------------- Long Tasks
CREATE TABLE longtasks (
	`id`			INT UNSIGNED AUTO_INCREMENT PRIMARY KEY
,	`type`			VARCHAR(255) CHARACTER SET utf8 COLLATE utf8_general_ci NOT NULL
,	`title`			VARCHAR(255) CHARACTER SET utf8 COLLATE utf8_general_ci NOT NULL
,	`status`		ENUM('not_started', 'cancel_pending', 'canceled', 'error', 'fatal_error', 'done', 'started') NOT NULL DEFAULT 'not_started'
,	`progress_text`		VARCHAR(245) CHARACTER SET utf8 COLLATE utf8_general_ci NOT NULL
,	`progress_max`		INT UNSIGNED NOT NULL DEFAULT 1
,	`progress_value`	INT UNSIGNED NOT NULL DEFAULT 0
,	`start_time`		TIMESTAMP
,	`finish_time`		TIMESTAMP
,	`owner_type`		SMALLINT UNSIGNED NOT NULL DEFAULT 0
,	`owner`			INT UNSIGNED NOT NULL DEFAULT 0
,	`can_cancel`		ENUM('false', 'true') NOT NULL DEFAULT 'false'
,	`pid`			INT UNSIGNED NOT NULL DEFAULT 0
) ENGINE=InnoDB;

CREATE TABLE longtaskparams (
	`task_id`		INT UNSIGNED NOT NULL
,	`param`			VARCHAR(245) CHARACTER SET ascii COLLATE ascii_general_ci NOT NULL
					-- parameter name
,	`val`			VARCHAR(255) CHARACTER SET binary
					-- parameter value
,				PRIMARY KEY (task_id, param)
) ENGINE=InnoDB;

-- Enhanced report
CREATE TABLE SiteAppsHitsStat (
  id int(10) UNSIGNED NOT NULL AUTO_INCREMENT,
  name varchar(255) CHARACTER SET utf8 COLLATE utf8_general_ci NOT NULL DEFAULT '',
  count bigint UNSIGNED NOT NULL DEFAULT '0',
  PRIMARY KEY  (id),
  UNIQUE KEY name (name)
) ENGINE=InnoDB;

CREATE TABLE `PleskPagesStat` (
  `date` DATE NOT NULL,
  `url` VARCHAR(255) CHARACTER SET utf8 COLLATE utf8_general_ci NOT NULL,
  `hits` bigint(20) UNSIGNED NOT NULL DEFAULT '0',
  PRIMARY KEY  (date, url)
) ENGINE=InnoDB;

CREATE TABLE `MailMessagesStat` (
  `date` DATE NOT NULL,
  `sent` BIGINT(20) UNSIGNED NOT NULL default '0',
  PRIMARY KEY  (date)
) ENGINE=InnoDB;

CREATE TABLE `SitePagesStat` (
  `date` DATE NOT NULL,
  `hits` BIGINT(20) UNSIGNED NOT NULL default '0',
  PRIMARY KEY  (date)
) ENGINE=InnoDB;

-- Webmails list
CREATE TABLE `Webmails` (
     `id` int(10) unsigned NOT NULL auto_increment,
    `product_id` varchar(255) character set ascii COLLATE ascii_bin NOT NULL,
    `name` varchar(255) character set utf8 COLLATE utf8_general_ci NOT NULL,
    `version` varchar(255) character set utf8 COLLATE utf8_general_ci NOT NULL,
     `release` varchar(255) character set utf8 COLLATE utf8_general_ci NOT NULL,
    `docroot` varchar(255) character set utf8 COLLATE utf8_general_ci NOT NULL,
    `enabled` enum('false', 'true') NOT NULL default 'false',
    PRIMARY KEY (`id`),
     UNIQUE KEY `product_id` (`product_id`),
	UNIQUE KEY `docroot` (`docroot`)
) ENGINE=InnoDB;

-- Greylisting support
CREATE TABLE `GL_settings` (
    `param` varchar(255) character set ascii COLLATE ascii_bin NOT NULL UNIQUE,
    `value` varchar(255) character set ascii COLLATE ascii_bin NOT NULL,
    PRIMARY KEY `param` (`param`)
) ENGINE=InnoDB;

CREATE TABLE `GL_remote_domains` (
    `domain` VARCHAR(255) character set ascii COLLATE ascii_bin NOT NULL UNIQUE
,   `type`   enum('black','white') NOT NULL DEFAULT 'black'
) ENGINE=InnoDB;

-- PersistentCache table
CREATE TABLE PersistentCache (
	`key`						VARCHAR(128) CHARACTER SET ascii COLLATE ascii_general_ci NOT NULL
,	`uid`						VARCHAR(32) CHARACTER SET ascii COLLATE ascii_general_ci NOT NULL
,	`expire`				TIMESTAMP
, `events`				VARCHAR(255) CHARACTER SET ascii COLLATE ascii_general_ci NOT NULL DEFAULT ''
, PRIMARY KEY (`key`, `uid`)
) ENGINE=InnoDB;

-- BackendCache table
CREATE TABLE BackendCache (
	`key`						VARCHAR(128) CHARACTER SET ascii COLLATE ascii_general_ci NOT NULL
,	`data`						BLOB NOT NULL DEFAULT ''
, PRIMARY KEY (`key`)
) ENGINE=InnoDB;

-- Configuration status
CREATE TABLE Configurations (
    `id`            INT UNSIGNED AUTO_INCREMENT PRIMARY KEY,
    `name`          VARCHAR(255) character set ascii COLLATE ascii_bin NOT NULL,
    `serviceNodeId` INT UNSIGNED NOT NULL DEFAULT 1,
    `file`          BLOB NOT NULL,
    `version`       VARCHAR(255) character set ascii COLLATE ascii_bin NOT NULL,
    `objectType`    VARCHAR(255) character set ascii COLLATE ascii_bin NOT NULL,
    `objectId`      INT UNSIGNED,
    `status`        enum('error', 'generation', 'ok') NOT NULL default 'error',
    `description`   BLOB DEFAULT NULL,
    INDEX objectTypeAndId_index (objectType, objectId)
) ENGINE=InnoDB;

-- External webmails
CREATE TABLE externalWebmails (
	`id` INT UNSIGNED AUTO_INCREMENT PRIMARY KEY,
	`name` VARCHAR(255) CHARACTER SET utf8 COLLATE utf8_general_ci,
	`url` VARCHAR(255) CHARACTER SET utf8 COLLATE utf8_general_ci,
	`enabled` int(10),
	UNIQUE (`name`)
) ENGINE=InnoDB;

-- APS Bundle filters
CREATE TABLE smb_apsBundleFilters (
	`id` INT UNSIGNED AUTO_INCREMENT PRIMARY KEY,
	`type` enum('white', 'black') NOT NULL default 'black'
) ENGINE=InnoDB;

CREATE TABLE smb_apsBundleFilterItems (
	`id` INT UNSIGNED AUTO_INCREMENT PRIMARY KEY,
	`filterId` INT UNSIGNED NOT NULL,
	`propertyName` VARCHAR(255) CHARACTER SET utf8 COLLATE utf8_general_ci,
	`propertyValue` VARCHAR(255) CHARACTER SET utf8 COLLATE utf8_general_ci,
	INDEX (filterId)
) ENGINE=InnoDB;

CREATE TABLE `ApiRpcCallsStat` (
  `id` int(10) unsigned NOT NULL auto_increment PRIMARY KEY,
  `Version` varchar(7) CHARACTER SET utf8 COLLATE utf8_general_ci NOT NULL default '',
  `Operator` varchar(50) CHARACTER SET utf8 COLLATE utf8_general_ci NOT NULL default '',
  `Command` varchar(50) CHARACTER SET utf8 COLLATE utf8_general_ci NOT NULL default '',
  `Session` varchar(8) CHARACTER SET utf8 COLLATE utf8_general_ci NOT NULL default '0',
  `FilterName` varchar(50) CHARACTER SET utf8 COLLATE utf8_general_ci NOT NULL default '0',
  `GroupOperation` int(10) NOT NULL default '0',
  `LastExecutionDate` datetime NOT NULL default '0000-00-00 00:00:00',
  `Count` int(10) unsigned NOT NULL default '0',
  UNIQUE KEY `LogItem` (`Version`,`Operator`,`Command`,`Session`,`FilterName`,`GroupOperation`)
) ENGINE=InnoDB;

-- IP Collections table
CREATE TABLE IpCollections (
  `id` INT UNSIGNED AUTO_INCREMENT NOT NULL PRIMARY KEY
) ENGINE=InnoDB;

-- IP Collection elements table
CREATE TABLE IpAddressesCollections (
  `ipCollectionId` INT UNSIGNED NOT NULL,
  `ipAddressId` INT UNSIGNED NOT NULL,
  PRIMARY KEY (`ipCollectionId`, `ipAddressId`)
) ENGINE=InnoDB;

--
-- Shared APS Controller integration data.
--

-- Information about hosting panel resources used for APS applications
CREATE TABLE apsResources (
  `id` INT UNSIGNED AUTO_INCREMENT NOT NULL PRIMARY KEY,
  `registryId` VARCHAR(36) CHARACTER SET ascii COLLATE ascii_general_ci NOT NULL,
  `pleskType` VARCHAR(255) CHARACTER SET ascii COLLATE ascii_general_ci NOT NULL,
  `pleskId` INT UNSIGNED NOT NULL
) ENGINE=InnoDB;

-- Runtime parameters of hosting panel resources used for APS applications
CREATE TABLE apsResourcesParameters (
  `id` INT UNSIGNED AUTO_INCREMENT NOT NULL PRIMARY KEY,
  `apsResourceId` INT UNSIGNED NOT NULL,
  `name` VARCHAR(255) CHARACTER SET utf8 COLLATE utf8_general_ci NOT NULL,
  `value` VARCHAR(255) CHARACTER SET utf8 COLLATE utf8_general_ci NOT NULL default ''
) ENGINE=InnoDB;

-- Information about hosting panel contexts used for APS applications
CREATE TABLE apsContexts (
  `id` INT UNSIGNED AUTO_INCREMENT NOT NULL PRIMARY KEY,
  `pleskType`  VARCHAR(255) CHARACTER SET ascii COLLATE ascii_general_ci NOT NULL,
  `pleskId` INT UNSIGNED NOT NULL,
  `ssl` ENUM('false','true') NOT NULL DEFAULT 'false',
  `subscriptionId` INT UNSIGNED DEFAULT 0
) ENGINE=InnoDB;

-- Set of Shared APS Controller Application Resources IDs linked to hosting contexts
CREATE TABLE apsContextsApplications (
  `id` INT UNSIGNED AUTO_INCREMENT NOT NULL PRIMARY KEY,
  `apsContextId` INT UNSIGNED NOT NULL,
  `registryApplicationId` VARCHAR(36) CHARACTER SET ascii COLLATE ascii_general_ci NOT NULL
) ENGINE=InnoDB;

-- Service Nodes
CREATE TABLE ServiceNodes (
  `id` INT UNSIGNED AUTO_INCREMENT NOT NULL PRIMARY KEY,
  `name` VARCHAR(255) CHARACTER SET ascii COLLATE ascii_general_ci NOT NULL,
  `transport` enum('local', 'remote') NOT NULL,
  `remoteIpAddress` VARCHAR(255) CHARACTER SET ascii COLLATE ascii_general_ci DEFAULT NULL,
  `accessKey` TEXT CHARACTER SET ascii COLLATE ascii_bin DEFAULT NULL,
  `externalId` VARCHAR(255) CHARACTER SET ascii COLLATE ascii_bin NOT NULL DEFAULT '',

  UNIQUE (`name`)
) ENGINE=InnoDB;

CREATE TABLE ServiceNodeProperties (
  `serviceNodeId` INT UNSIGNED NOT NULL,
  `name` VARCHAR(255) CHARACTER SET ascii COLLATE ascii_general_ci NOT NULL,
  `value` BLOB NOT NULL,
  PRIMARY KEY (`serviceNodeId`, `name`)
) ENGINE=InnoDB;

CREATE TABLE `ServiceNodeCertificates` (
  `serviceNodeId` int unsigned NOT NULL,
  `certificateId` int unsigned NOT NULL,
  `certFile` VARCHAR(255) CHARACTER SET ascii COLLATE ascii_bin NOT NULL DEFAULT '',
  `caFile` VARCHAR(255) CHARACTER SET ascii COLLATE ascii_bin NOT NULL DEFAULT '',
  PRIMARY KEY  (`serviceNodeId`,`certificateId`)
) ENGINE=InnoDB;

CREATE TABLE ServiceNodeCache (
  `serviceNodeId` INT UNSIGNED NOT NULL,
                -- ID, service node where specified data was cached
  `pathId` VARCHAR(255) CHARACTER SET ascii COLLATE ascii_general_ci NOT NULL,
                -- MD5, checksumm of original path (used for indexing and fast search by original path)
  `path` TEXT CHARACTER SET ascii COLLATE ascii_bin,
                -- string, original path (path on management node)
  `cache` TEXT CHARACTER SET ascii COLLATE ascii_bin,
                -- string, cached path (path on service node)
  PRIMARY KEY (`serviceNodeId`, `pathId`)
) ENGINE=InnoDB;

-- Main PMM table
CREATE TABLE IF NOT EXISTS PMM (
    sessionId varchar(250) CHARACTER SET binary NOT NULL,
    param     varchar(250) CHARACTER SET ascii COLLATE ascii_general_ci NOT NULL,
    val       varchar(255) CHARACTER SET binary,
    PRIMARY KEY (sessionId, param)
) ENGINE=InnoDB;

-- Saved PMM params from last migration session (defaults)
CREATE TABLE IF NOT EXISTS PMMDefault (
    param varchar(255) CHARACTER SET ascii COLLATE ascii_general_ci NOT NULL,
    val   varchar(255) CHARACTER SET binary,
    PRIMARY KEY (param)
) ENGINE=InnoDB;

-- PBM tables

CREATE TABLE IF NOT EXISTS BackupsScheduled (
    id      INT UNSIGNED AUTO_INCREMENT PRIMARY KEY
,   obj_id      INT UNSIGNED NOT NULL
,   obj_type    ENUM('server', 'reseller', 'client', 'domain') NOT NULL
,   repository  ENUM('local', 'ftp') NOT NULL default 'local'
,   last        DATETIME DEFAULT NULL
,   period      INT UNSIGNED NOT NULL
,   active      ENUM('true', 'false') NOT NULL
,   processed   ENUM('true', 'false') NOT NULL
,   rotation    INT NOT NULL default 0
,   prefix      varchar(255) CHARACTER SET utf8 COLLATE utf8_general_ci
,   email       varchar(255) CHARACTER SET utf8 COLLATE utf8_general_ci
,   split_size  INT UNSIGNED NOT NULL DEFAULT '0'
,   suspend     ENUM('true', 'false') NOT NULL default 'false'
,   with_content    ENUM('true', 'false') NOT NULL default 'true'
,   backup_day  INT UNSIGNED NOT NULL default '0'
,   backup_time TIME NOT NULL default '00:00:00'
,   content_type ENUM('backup_content_all_at_domain', 'backup_content_vhost_only', 'backup_content_mail_only') DEFAULT 'backup_content_all_at_domain'
) ENGINE=InnoDB;

CREATE TABLE IF NOT EXISTS BackupsSettings (
    id int unsigned default NULL,
    type enum('domain','client','server') NOT NULL default 'domain',
    param varchar(255) NOT NULL default '',
    value varchar(255) character set utf8 default NULL,
    UNIQUE KEY `index1` (`id`,`type`,`param`)
) ENGINE=InnoDB;

-- suspend_handler history table
CREATE TABLE IF NOT EXISTS suspend_handler_history (
    dom_id     INT UNSIGNED NOT NULL
               -- domain ID
,   session_id VARCHAR(255) CHARACTER SET binary
               -- dump name
) ENGINE=InnoDB;

-- API-RPC tables
CREATE TABLE IF NOT EXISTS exp_event (
	id      BIGINT(10) UNSIGNED NOT NULL AUTO_INCREMENT PRIMARY KEY,
	source      ENUM('pa', 'plesk'),    -- Event producer

	event_type  ENUM(
		'started', 'stopped',
		'created', 'updated', 'deleted', 'status_changed',
		'terminated', 'flushed',
		'installed', 'uninstalled',
		'siteapp_added', 'siteapp_removed',
		'expired', 'exceeded', 'guid_changed'
	) NOT NULL,     -- Type of event occurred
	event_time  DATETIME NOT NULL,  -- Time of event occurred

	obj_class   VARCHAR(255) CHARACTER SET utf8 COLLATE utf8_general_ci NOT NULL,     -- Evented object class
	obj_id      VARCHAR(255) CHARACTER SET utf8 COLLATE utf8_general_ci NOT NULL,   -- Evented object unique ID
	host        VARCHAR(255) CHARACTER SET utf8 COLLATE utf8_general_ci NOT NULL,
	`user`      VARCHAR(255) CHARACTER SET ascii COLLATE ascii_general_ci NOT NULL,
	flushed     ENUM('true', 'false') NOT NULL DEFAULT 'false'
);

CREATE TABLE IF NOT EXISTS secret_keys (
	key_id      VARCHAR(255) CHARACTER SET ascii COLLATE ascii_general_ci NOT NULL,
	ip_address  VARCHAR(39) CHARACTER SET ascii COLLATE ascii_general_ci NOT NULL,
	description VARCHAR(255) CHARACTER SET utf8 COLLATE utf8_general_ci NOT NULL,
	index(key_id)
);

-- File Sharing users
CREATE TABLE IF NOT EXISTS fileSharingUsers (
	`id` INT(11) NOT NULL AUTO_INCREMENT PRIMARY KEY,
	`userId` INT(11) NOT NULL,
	`login` VARCHAR(255) CHARACTER SET utf8 COLLATE utf8_general_ci NOT NULL,
	`password` VARCHAR(255) CHARACTER SET utf8 COLLATE utf8_general_ci,
	UNIQUE KEY `userId` (`userId`),
	UNIQUE KEY `login` (`login`)
) ENGINE=InnoDB;


CREATE TABLE IF NOT EXISTS PhpSettings (
    `id` INT UNSIGNED AUTO_INCREMENT PRIMARY KEY,
    `noteId` INT UNSIGNED DEFAULT 0
) ENGINE=InnoDB;

CREATE TABLE IF NOT EXISTS PhpSettingsParameters (
    `id` INT UNSIGNED NOT NULL,
    `name` VARCHAR(255) CHARACTER SET utf8 COLLATE utf8_general_ci NOT NULL,
    `value` VARCHAR(255) CHARACTER SET utf8 COLLATE utf8_general_ci,
    PRIMARY KEY (`id`, `name`)
) ENGINE=InnoDB;

-- ---------------------------------------------------------------------
-- FOREIGN KEY DECLARATIONS --------------------------------------------
-- ---------------------------------------------------------------------

-- TODO: uncomment this when 8.0 development starts.
-- See bug #34654 for details.

-- ALTER TABLE clients ADD FOREIGN KEY (account_id) REFERENCES accounts (id);
-- ALTER TABLE clients ADD FOREIGN KEY (limits_id) REFERENCES Limits (id);
-- ALTER TABLE clients ADD FOREIGN KEY (params_id) REFERENCES Parameters (id);
-- ALTER TABLE clients ADD FOREIGN KEY (perm_id) REFERENCES Permissions (id);
-- ALTER TABLE clients ADD FOREIGN KEY (pool_id) REFERENCES Repository (rep_id);
-- ALTER TABLE clients ADD FOREIGN KEY (logo_id) REFERENCES Logos (id);
-- ALTER TABLE clients ADD FOREIGN KEY (tmpl_id) REFERENCES Repository (rep_id);
-- ALTER TABLE clients ADD FOREIGN KEY (sapp_pool_id) REFERENCES Repository (rep_id);

-- ALTER TABLE cl_param ADD FOREIGN KEY (cl_id) REFERENCES clients (id);

-- ALTER TABLE dom_level_usrs ADD FOREIGN KEY (dom_id) REFERENCES domains (id);
-- ALTER TABLE dom_level_usrs ADD FOREIGN KEY (account_id) REFERENCES accounts (id);
-- ALTER TABLE dom_level_usrs ADD FOREIGN KEY (card_id) REFERENCES Cards (id);
-- ALTER TABLE dom_level_usrs ADD FOREIGN KEY (perm_id) REFERENCES Permissions (id);

-- ALTER TABLE domains ADD FOREIGN KEY (cl_id) REFERENCES clients (id);
-- ALTER TABLE domains ADD FOREIGN KEY (dns_zone_id) REFERENCES dns_zone (id);
-- ALTER TABLE domains ADD FOREIGN KEY (cert_rep_id) REFERENCES Repository (rep_id);
-- ALTER TABLE domains ADD FOREIGN KEY (limits_id) REFERENCES Limits (id);
-- ALTER TABLE domains ADD FOREIGN KEY (params_id) REFERENCES Parameters (id);

-- ALTER TABLE domainaliases ADD FOREIGN KEY (dns_zone_id) REFERENCES dns_zone (id);

-- ALTER TABLE dom_param ADD FOREIGN KEY (dom_id) REFERENCES domains (id);

-- ALTER TABLE subdomains ADD FOREIGN KEY (dom_id) REFERENCES domains (id);
-- ALTER TABLE subdomains ADD FOREIGN KEY (sys_user_id) REFERENCES sys_users (id);

-- ALTER TABLE DomainServices ADD FOREIGN KEY (dom_id) REFERENCES domains (id);
-- ALTER TABLE DomainServices ADD FOREIGN KEY (parameters_id) REFERENCES Parameters (id);

-- ALTER TABLE WebApps ADD FOREIGN KEY (domain_service_id) REFERENCES DomainServices (id);

-- ALTER TABLE disk_usage ADD FOREIGN KEY (dom_id) REFERENCES domains (id);

-- ALTER TABLE dns_recs ADD FOREIGN KEY (dns_zone_id) REFERENCES dns_zone (id);

-- ALTER TABLE hosting ADD FOREIGN KEY (dom_id) REFERENCES domains (id);
-- ALTER TABLE hosting ADD FOREIGN KEY (sys_user_id) REFERENCES sys_users (id);
-- ALTER TABLE hosting ADD FOREIGN KEY (ip_address_id) REFERENCES IP_Addresses (id);

-- ALTER TABLE web_users ADD FOREIGN KEY (dom_id) REFERENCES domains (id);
-- ALTER TABLE web_users ADD FOREIGN KEY (sys_user_id) REFERENCES sys_users (id);

-- ALTER TABLE protected_dirs ADD FOREIGN KEY (dom_id) REFERENCES domains (id);

-- ALTER TABLE pd_users ADD FOREIGN KEY (account_id) REFERENCES accounts (id);
-- ALTER TABLE pd_users ADD FOREIGN KEY (pd_id) REFERENCES protected_dirs (id);

-- ALTER TABLE forwarding ADD FOREIGN KEY (dom_id) REFERENCES domains (id);
-- ALTER TABLE forwarding ADD FOREIGN KEY (ip_address_id) REFERENCES IP_Addresses (id);

-- ALTER TABLE anon_ftp ADD FOREIGN KEY (dom_id) REFERENCES domains (id);

-- ALTER TABLE DomainsTraffic ADD FOREIGN KEY (dom_id) REFERENCES domains (id);

-- ALTER TABLE ClientsTraffic ADD FOREIGN KEY (cl_id) REFERENCES clients (id);

-- ALTER TABLE mail ADD FOREIGN KEY (perm_id) REFERENCES Permissions (id);
-- ALTER TABLE mail ADD FOREIGN KEY (account_id) REFERENCES accounts (id);
-- ALTER TABLE mail ADD FOREIGN KEY (dom_id) REFERENCES domains (id);

-- ALTER TABLE mail_aliases ADD FOREIGN KEY (mn_id) REFERENCES mail (id);

-- ALTER TABLE mail_redir ADD FOREIGN KEY (mn_id) REFERENCES mail (id);

-- ALTER TABLE mail_resp ADD FOREIGN KEY (mn_id) REFERENCES mail (id);

-- ALTER TABLE resp_freq ADD FOREIGN KEY (rn_id) REFERENCES mail_resp (id);

-- ALTER TABLE resp_attach ADD FOREIGN KEY (rn_id) REFERENCES mail_resp (id);

-- ALTER TABLE resp_forward ADD FOREIGN KEY (rn_id) REFERENCES mail_resp (id);

-- ALTER TABLE mn_param ADD FOREIGN KEY (mn_id) REFERENCES mail (id);

-- ALTER TABLE Notifications ADD FOREIGN KEY (note_id) REFERENCES Notes (id);

-- ALTER TABLE data_bases ADD FOREIGN KEY (dom_id) REFERENCES domains (id);

-- ALTER TABLE db_users ADD FOREIGN KEY (account_id) REFERENCES accounts (id);
-- ALTER TABLE db_users ADD FOREIGN KEY (db_id) REFERENCES data_bases (id);

-- ALTER TABLE sys_users ADD FOREIGN KEY (account_id) REFERENCES accounts (id);

-- ALTER TABLE Templates ADD FOREIGN KEY (note_id) REFERENCES Notes (id);

-- ALTER TABLE TmplData ADD FOREIGN KEY (tmpl_id) REFERENCES Templates (id);

-- ALTER TABLE itmpl_data ADD FOREIGN KEY (itmpl_id) REFERENCES itmpl (id);

-- ALTER TABLE slave_params ADD FOREIGN KEY (slave_id) REFERENCES slaves (id);

-- ALTER TABLE IP_Addresses ADD FOREIGN KEY (ssl_certificate_id) REFERENCES certificates (id);
-- ALTER TABLE IP_Addresses ADD FOREIGN KEY (default_domain_id) REFERENCES hosting (dom_id) ON DELETE SET NULL;

-- ALTER TABLE log_actions ADD FOREIGN KEY (action_id) REFERENCES actions (id);

-- ALTER TABLE log_components ADD FOREIGN KEY (action_id) REFERENCES log_actions (id);

-- ALTER TABLE event_handlers ADD FOREIGN KEY (action_id) REFERENCES actions (id);

-- ALTER TABLE MailLists ADD FOREIGN KEY (dom_id) REFERENCES domains (id);

-- ALTER TABLE report_section ADD FOREIGN KEY (report_id) REFERENCES report (id);

-- ALTER TABLE report_auto ADD FOREIGN KEY (report_id) REFERENCES report (id);
-- ALTER TABLE report_auto ADD FOREIGN KEY (client) REFERENCES clients (id);
-- ALTER TABLE report_auto ADD FOREIGN KEY (domain) REFERENCES domains (id);

-- ALTER TABLE SiteApps ADD FOREIGN KEY (capp_item_id) REFERENCES APSClientApplicationItems (id);
-- ALTER TABLE SiteApps ADD FOREIGN KEY (params_id) REFERENCES Parameters (id);
-- ALTER TABLE SiteApps ADD FOREIGN KEY (`license_id`) REFERENCES APSLicenses (id);

-- ALTER TABLE APSClientApplicationItems ADD FOREIGN KEY (`client_id`) REFERENCES clients (id);
-- ALTER TABLE APSClientApplicationItems ADD FOREIGN KEY (`app_item_id`) REFERENCES APSApplicationItems (id);

-- ALTER TABLE APSApplicationItems ADD FOREIGN KEY (`pkg_id`) REFERENCES SiteAppPackages (id);

-- ALTER TABLE SiteAppResources ADD FOREIGN KEY (app_id) REFERENCES SiteApps (id);

-- ALTER TABLE SiteAppFiles ADD FOREIGN KEY (instance_id) REFERENCES SiteApps (id);

-- ALTER TABLE spamfilter_preferences ADD FOREIGN KEY (spamfilter_id) REFERENCES spamfilter (id);

-- ALTER TABLE key_history_params ADD FOREIGN KEY (key_id) REFERENCES key_history (id);

-- ALTER TABLE webalizer_hidden_referrer ADD FOREIGN KEY (dom_id) REFERENCES domains (id);

-- ALTER TABLE webalizer_group_referrer ADD FOREIGN KEY (dom_id) REFERENCES domains (id);
-- ALTER TABLE DashboardPresetConfig ADD FOREIGN KEY (preset_id) REFERENCES DashboardPreset (id);

-- ALTER TABLE SBReseller ADD FOREIGN KEY (client_id) REFERENCES clients (id);
-- ALTER TABLE SBSite ADD FOREIGN KEY (virtualHost_id) REFERENCES domains (id);


-- ---------------------------------------------------------------------
-- DATA INSERTION ------------------------------------------------------
-- ---------------------------------------------------------------------

-- replace into locales (id) values('en-US');

-- replace into misc (param,val) values('admin_email', 'user@example-mail.com');
-- replace into misc (param,val) values('NameVirtualHost', '192.168.2.14');
-- replace into misc (param,val) values('def_locale', 'en-US');
REPLACE INTO misc (param,val) VALUES('def_skin_id',  '1');
REPLACE INTO misc (param,val) VALUES('admin_skin_id',  '1');

replace into misc (param,val) values('include_logs', 		'true');
replace into misc (param,val) values('include_databases',	'true');
replace into misc (param,val) values('include_mailboxes',	'true');
replace into misc (param,val) values('include_webapps',		'true');
replace into misc (param,val) values('include_maillists',	'true');
replace into misc (param,val) values('include_domaindumps',	'true');

replace into misc (param,val) values('size_count_type',		'block');

replace into misc (param,val) values('login_timeout', '30');

replace into misc (param,val) values('relay', 'open');
replace into misc (param,val) values('relay', 'closed');
replace into misc (param,val) values('relay', 'auth');
replace into misc (param,val) values('disable_smtp_auth', '0');
replace into misc (param,val) values('disable_pop_auth', '1');
replace into misc (param,val) values('poplock_time', '20');
replace into misc (param,val) values('allow_short_pop3_names', 'disabled');

replace into misc (param,val) values('actionlog_rot_type', 			'by_period');
replace into misc (param,val) values('actionlog_rot_period', 		'day');
replace into misc (param,val) values('actionlog_rot_num_periods', 	'30');
replace into misc (param,val) values('actionlog_rot_num_records', 	'3000');

replace into misc (param,val) values ('restart_apache_interval', '0');

replace into misc (param,val) values('slave_request_timeout', '20');
replace into misc (param,val) values('slave_services_list_with_non_obligatory_status_checking', 'tomcat,postgresql,coldfusion,spamd');
replace into misc (param,val) values('master_services_list_for_obligatory_status_checking', 'pop3,smtp,http,ftp,dns'); -- imap
replace into misc (param,val) values('admin_itmpl_id', '1'); -- default visibility template
replace into misc (param,val) values('def_itmpl_id', '1'); -- default visibility template

-- Bug 23703 enable multy login bu defautl
replace into misc (param,val) values('multiply_login', 'true');
replace into misc (param,val) values('dns_recursion', 'localnets');

-- set drweb as default antivirus filter
replace into misc (param,val) values('virusfilter', 'drweb');
replace into misc (param,val) values('admin_password_encrypted', 'true');

replace into dns_recs_t(displayHost, host, type, displayVal, val, time_stamp)		values("<domain>.", "<domain>.", "NS", "ns.<domain>.", "ns.<domain>.", NOW());
replace into dns_recs_t(displayHost, host, type, displayVal, val, time_stamp)		values("ns.<domain>.", "ns.<domain>.", "A", "<ip>", "<ip>", NOW()+1);
replace into dns_recs_t(displayHost, host, type, displayVal, val, time_stamp)		values("ns.<domain>.", "ns.<domain>.", "AAAA", "<ipv6>", "<ipv6>", NOW()+2);
replace into dns_recs_t(displayHost, host, type, displayVal, val, time_stamp)		values("<domain>.", "<domain>.", "A", "<ip>", "<ip>", NOW()+3);
replace into dns_recs_t(displayHost, host, type, displayVal, val, time_stamp)		values("<domain>.", "<domain>.", "AAAA", "<ipv6>", "<ipv6>", NOW()+4);
replace into dns_recs_t(displayHost, host, type, displayVal, val, time_stamp)		values("webmail.<domain>.", "webmail.<domain>.", "A", "<ip>", "<ip>", NOW()+5);
replace into dns_recs_t(displayHost, host, type, displayVal, val, time_stamp)		values("webmail.<domain>.", "webmail.<domain>.", "AAAA", "<ipv6>", "<ipv6>", NOW()+6);
replace into dns_recs_t(displayHost, host, type, displayVal, val, opt, time_stamp)	values("<domain>.", "<domain>.", "MX", "mail.<domain>.", "mail.<domain>.", 10, NOW()+7);
replace into dns_recs_t(displayHost, host, type, displayVal, val, time_stamp)		values("mail.<domain>.", "mail.<domain>.", "A", "<ip>", "<ip>", NOW()+8);
replace into dns_recs_t(displayHost, host, type, displayVal, val, time_stamp)		values("mail.<domain>.", "mail.<domain>.", "AAAA", "<ipv6>", "<ipv6>", NOW()+9);
replace into dns_recs_t(displayHost, host, type, displayVal, val, time_stamp)		values("ipv4.<domain>.", "ipv4.<domain>.", "A", "<ip>", "<ip>", NOW()+10);
replace into dns_recs_t(displayHost, host, type, displayVal, val, time_stamp)		values("ipv6.<domain>.", "ipv6.<domain>.", "AAAA", "<ipv6>", "<ipv6>", NOW()+11);
replace into dns_recs_t(displayHost, host, type, displayVal, val, time_stamp)		values("ftp.<domain>.", "ftp.<domain>.", "CNAME", "<domain>.", "<domain>.", NOW()+12);
replace into dns_recs_t(displayHost, host, type, displayVal, val, opt, time_stamp)	values("<ip>", "<ip>", "PTR", "<domain>.", "<domain>.", 24, NOW()+13);
replace into dns_recs_t(displayHost, host, type, displayVal, val, time_stamp) values("<domain>.", "<domain>.", "TXT", "v=spf1 +a +mx -all", "v=spf1 +a +mx -all", NOW()+14);
replace into dns_recs_t(displayHost, host, type, displayVal, val, opt, time_stamp)	values("<ipv6>", "<ipv6>", "PTR", "<domain>.", "<domain>.", 64, NOW()+15);

delete from Skins;
replace into Skins (id, name, place) values (1, 'Default','default');

delete from actions;
replace into actions(name, descr, enabled) values ('admin_update', 'Update Administrator Information', 'true');
replace into actions(name, descr, enabled) values ('service_stop', 'Stop Service', 'true');
replace into actions(name, descr, enabled) values ('service_start', 'Start Service', 'true');
replace into actions(name, descr, enabled) values ('service_restart', 'Restart Service', 'true');
replace into actions(name, descr, enabled) values ('ip_address_create', 'Create IP Address', 'true');
replace into actions(name, descr, enabled) values ('ip_address_update', 'Update IP Address', 'true');
replace into actions(name, descr, enabled) values ('ip_address_delete', 'Delete IP Address', 'true');
replace into actions(name, descr, enabled) values ('client_create', 'Create Client', 'true');
replace into actions(name, descr, enabled) values ('client_update', 'Update Client', 'true');
replace into actions(name, descr, enabled) values ('client_delete', 'Delete Client', 'true');
replace into actions(name, descr, enabled) values ('client_status_update', 'Update Client Status', 'true');
replace into actions(name, descr, enabled) values ('client_preferences_update', 'Update Client Preferences', 'true');
replace into actions(name, descr, enabled) values ('client_ip_pool_update', 'Update Client IP Pool', 'true');
replace into actions(name, descr, enabled) values ('client_siteapp_added', 'Site Application Package added to Client Pool', 'true');
replace into actions(name, descr, enabled) values ('client_siteapp_removed', 'Site Application Package removed from Client Pool', 'true');
replace into actions(name, descr, enabled) values ('client_limit_size_reached', 'Client\'s disk space limit reached', 'true');
replace into actions(name, descr, enabled) values ('client_limit_traffic_reached', 'Client\'s traffic limit reached', 'true');

replace into actions(name, descr, enabled) values ('reseller_create', 'Create Reseller', 'true');
replace into actions(name, descr, enabled) values ('reseller_update', 'Update Reseller', 'true');
replace into actions(name, descr, enabled) values ('reseller_delete', 'Delete Reseller', 'true');
replace into actions(name, descr, enabled) values ('reseller_status_update', 'Update Reseller Status', 'true');
replace into actions(name, descr, enabled) values ('reseller_preferences_update', 'Update Reseller Preferences', 'true');
replace into actions(name, descr, enabled) values ('reseller_ip_pool_update', 'Update Reseller IP Pool', 'true');
replace into actions(name, descr, enabled) values ('reseller_siteapp_added', 'Site Application Package added to Reseller Pool', 'true');
replace into actions(name, descr, enabled) values ('reseller_siteapp_removed', 'Site Application Package removed from Reseller Pool', 'true');
replace into actions(name, descr, enabled) values ('reseller_limit_size_reached', 'Reseller\'s disk space limit reached', 'true');
replace into actions(name, descr, enabled) values ('reseller_limit_traffic_reached', 'Reseller\'s traffic limit reached', 'true');

replace into actions(name, descr, enabled) values ('dashboard_preset_create', 'Create Desktop Preset', 'true');
replace into actions(name, descr, enabled) values ('dashboard_preset_update', 'Update Desktop Preset', 'true');
replace into actions(name, descr, enabled) values ('dashboard_preset_delete', 'Delete Desktop Preset', 'true');
replace into actions(name, descr, enabled) values ('domain_create', 'Create Domain', 'true');
replace into actions(name, descr, enabled) values ('domain_update', 'Update Domain', 'true');
replace into actions(name, descr, enabled) values ('domain_delete', 'Delete Domain', 'true');
replace into actions(name, descr, enabled) values ('domain_owner_change', 'Change Domain Owner', 'true');
replace into actions(name, descr, enabled) values ('domain_status_update', 'Update Domain Status', 'true');
replace into actions(name, descr, enabled) values ('domain_dns_update', 'Update Domain DNS Zone', 'true');
replace into actions(name, descr, enabled) values ('domain_limit_size_reached', 'Domain\'s disk space limit reached', 'true');
replace into actions(name, descr, enabled) values ('domain_limit_traffic_reached', 'Domain\'s traffic limit reached', 'true');
replace into actions(name, descr, enabled) values ('subdomain_create', 'Create Subdomain', 'true');
replace into actions(name, descr, enabled) values ('subdomain_update', 'Update Subdomain', 'true');
replace into actions(name, descr, enabled) values ('subdomain_delete', 'Delete Subdomain', 'true');
replace into actions(name, descr, enabled) values ('domain_alias_create', 'Create domain alias', 'true');
replace into actions(name, descr, enabled) values ('domain_alias_update', 'Update domain alias', 'true');
replace into actions(name, descr, enabled) values ('domain_alias_delete', 'Delete domain alias', 'true');
replace into actions(name, descr, enabled) values ('domain_alias_dns_update', 'Update Domain alias DNS Zone', 'true');
replace into actions(name, descr, enabled) values ('phys_hosting_create', 'Create Physical Hosting', 'true');
replace into actions(name, descr, enabled) values ('phys_hosting_update', 'Update Physical Hosting', 'true');
replace into actions(name, descr, enabled) values ('phys_hosting_delete', 'Delete Physical Hosting', 'true');
replace into actions(name, descr, enabled) values ('forwarding_create', 'Create Standard/Frame forwarding', 'true');
replace into actions(name, descr, enabled) values ('forwarding_update', 'Update Standard/Frame forwarding', 'true');
replace into actions(name, descr, enabled) values ('forwarding_delete', 'Delete Standard/Frame forwarding', 'true');
replace into actions(name, descr, enabled) values ('mailname_create', 'Create Mailname', 'true');
replace into actions(name, descr, enabled) values ('mailname_update', 'Update Mailname', 'true');
replace into actions(name, descr, enabled) values ('mailname_delete', 'Delete Mailname', 'true');
replace into actions(name, descr, enabled) values ('webuser_create', 'Create WebUser', 'true');
replace into actions(name, descr, enabled) values ('webuser_update', 'Update WebUser', 'true');
replace into actions(name, descr, enabled) values ('webuser_delete', 'Delete WebUser', 'true');
replace into actions(name, descr, enabled) values ('client_limits_update', 'Update Client Limits', 'true');

replace into actions(name, descr, enabled) values ('reseller_limits_update', 'Update Reseller Limits', 'true');

replace into actions(name, descr, enabled) values ('domain_limits_update', 'Update Domain Limits', 'true');
replace into actions(name, descr, enabled) values ('client_permissions_update', 'Update Client Permissions', 'true');

replace into actions(name, descr, enabled) values ('reseller_permissions_update', 'Update Reseller Permissions', 'true');

replace into actions(name, descr, enabled) values ('maillist_create', 'Create Mail list', 'true');
replace into actions(name, descr, enabled) values ('maillist_update', 'Update Mail list', 'true');
replace into actions(name, descr, enabled) values ('maillist_delete', 'Delete Mail list', 'true');
replace into actions(name, descr, enabled) values ('cp_user_login', 'CP User Login', 'true');
replace into actions(name, descr, enabled) values ('cp_user_logout', 'CP User Logout', 'true');
replace into actions(name, descr, enabled) values ('dl_user_update', 'Domain Administrator Update', 'true');

replace into actions(name, descr, enabled) values ('siteapp_install', 'Install Site Application', 'true');
replace into actions(name, descr, enabled) values ('siteapp_reconfigure', 'Reconfigure Site Application', 'true');
replace into actions(name, descr, enabled) values ('siteapp_uninstall', 'Uninstall site application', 'true');
replace into actions(name, descr, enabled) values ('siteapp_upgrade', 'Upgrade site application', 'true');

replace into actions(name, descr, enabled) values ('license_update', 'License updated', 'true');
replace into actions(name, descr, enabled) values ('license_expired', 'License expired', 'true');

replace into actions(name, descr, enabled) values ('database_server_create', 'Create database server', 'true');
replace into actions(name, descr, enabled) values ('database_server_update', 'Update database server', 'true');
replace into actions(name, descr, enabled) values ('database_server_delete', 'Delete database server', 'true');

replace into actions(name, descr, enabled) values ('database_create', 'Create database', 'true');
replace into actions(name, descr, enabled) values ('database_delete', 'Delete database', 'true');

replace into actions(name, descr, enabled) values ('database_user_create', 'Create database user', 'true');
replace into actions(name, descr, enabled) values ('database_user_update', 'Update database user', 'true');
replace into actions(name, descr, enabled) values ('database_user_delete', 'Delete database user', 'true');

replace into actions(name, descr, enabled) values ('session_preferences_update', 'Login settings updated', 'true');

replace into actions(name, descr, enabled) values ('plesk_component_upgrade', 'Plesk component upgrade', 'true');

replace into actions(name, descr, enabled) values ('client_guid_update', 'Change Client GUID', 'true');

replace into actions(name, descr, enabled) values ('reseller_guid_update', 'Change Reseller GUID', 'true');

replace into actions(name, descr, enabled) values ('domain_guid_update', 'Change Domain GUID', 'true');

replace into actions(name, descr, enabled) values('template_client_create', 'Create client template', 'true');
replace into actions(name, descr, enabled) values('template_client_update', 'Update client template', 'true');
replace into actions(name, descr, enabled) values('template_client_delete', 'Delete client template', 'true');
replace into actions(name, descr, enabled) values('template_admin_create', 'Create domain template by admin', 'true');
replace into actions(name, descr, enabled) values('template_admin_update', 'Update domain template by admin', 'true');
replace into actions(name, descr, enabled) values('template_admin_delete', 'Delete domain template by admin', 'true');
replace into actions(name, descr, enabled) values('template_domain_create', 'Create domain template by client', 'true');
replace into actions(name, descr, enabled) values('template_domain_update', 'Update domain template by client', 'true');
replace into actions(name, descr, enabled) values('template_domain_delete', 'Delete domain template by client', 'true');
replace into actions(name, descr, enabled) values('template_reseller_create', 'Create reseller template', 'true');
replace into actions(name, descr, enabled) values('template_reseller_update', 'Update reseller template', 'true');
replace into actions(name, descr, enabled) values('template_reseller_delete', 'Delete reseller template', 'true');

replace into actions(name, descr, enabled) values('ftpuser_create', 'Create FTP User', 'true');
replace into actions(name, descr, enabled) values('ftpuser_update', 'Update FTP User', 'true');
replace into actions(name, descr, enabled) values('ftpuser_delete', 'Delete FTP User', 'true');

replace into actions(name, descr, enabled) values ('health_status_change', 'Server health status changed', 'true');

replace into actions(name, descr, enabled) values ('site_create', 'Create additional domain', 'true');
replace into actions(name, descr, enabled) values ('site_update', 'Update additional domain', 'true');
replace into actions(name, descr, enabled) values ('site_delete', 'Delete additional domain', 'true');
replace into actions(name, descr, enabled) values ('site_status_update', 'Change status of additional domain', 'true');
replace into actions(name, descr, enabled) values ('site_dns_update', 'Update additional domain DNS zone status', 'true');
replace into actions(name, descr, enabled) values ('site_guid_update', 'Change site guid', 'true');

replace into actions(name, descr, enabled) values ('site_alias_create', 'Create alias for additional domain', 'true');
replace into actions(name, descr, enabled) values ('site_alias_update', 'Update alias for additional domain', 'true');
replace into actions(name, descr, enabled) values ('site_alias_delete', 'Delete alias for additional domain', 'true');
replace into actions(name, descr, enabled) values ('site_alias_dns_update', 'Update DNS zone for alias for additional domain', 'true');

replace into actions(name, descr, enabled) values ('site_subdomain_create', 'Create subdomain for additional domain', 'true');
replace into actions(name, descr, enabled) values ('site_subdomain_update', 'Update subdomain for additional domain', 'true');
replace into actions(name, descr, enabled) values ('site_subdomain_delete', 'Delete subdomain for additional domain', 'true');

replace into actions(name, descr, enabled) values ('subdomain_dns_update', 'Update subdomain DNS zone status', 'true');
replace into actions(name, descr, enabled) values ('site_subdomain_dns_update', 'Update DNS zone of subdomain for additional domain status', 'true');

replace into itmpl (id,name) values(1, 'Interface customization template');

-- enable Mailman localhost relaying
REPLACE INTO smtp_poplocks (ip_address, ip_mask) VALUES ('127.0.0.0','8');
REPLACE INTO smtp_poplocks (ip_address, ip_mask) VALUES ('::1','128');

REPLACE INTO DatabaseServers (id, host, port, type, admin_login, admin_password, last_error, `server_version`) VALUES (1, 'localhost', 3306, 'mysql', 'admin', '********', 'no_error', '');
REPLACE INTO DatabaseServers (id, host, port, type, admin_login, admin_password, last_error, `server_version`) VALUES (2, 'localhost', 5432, 'postgresql', '', '', 'credentials_not_set', '');

REPLACE INTO misc (param, val) VALUES ('default_server_mysql', '1');
REPLACE INTO misc (param, val) VALUES ('default_server_postgresql', '2');

-- default presets configuration
REPLACE INTO DashboardPreset (id, uri, name, type) values (1, '/plesk/dashboard/', 'Default Administrator Home Page', 'admin');
REPLACE INTO misc (param, val) VALUES ('def_admin_preset_id', 1);
REPLACE INTO misc (param, val) VALUES ('admin_preset_id', 1);

REPLACE INTO DashboardPreset (id, uri, name, type) values (2, '/plesk/client@/dashboard/', 'Default Client Home Page', 'client');
REPLACE INTO misc (param, val) VALUES ('def_client_preset_id', 2);

REPLACE INTO DashboardPreset (id, uri, name, type) values (3, '/plesk/client@/domain@/dashboard/', 'Default Domain Owner Home Page', 'domain');
REPLACE INTO misc (param, val) VALUES ('def_domain_preset_id', 3);

REPLACE INTO DashboardPreset (id, uri, name, type) values (4, '/plesk/reseller@/dashboard/', 'Default Reseller Home Page', 'reseller');
REPLACE INTO misc (param, val) VALUES ('def_reseller_preset_id', 4);

-- PSA database version upgrade
-- replace into misc (param,val) values('version', '0650');	-- just for info, filled by installer

-- SOA Serial
REPLACE INTO misc (param, val) VALUES ('soa_serial_format', 'UNIXTIMESTAMP');

-- Greylisting settings(in minutes)
REPLACE INTO GL_settings (param, value) VALUES ('greyInterval', '5');
REPLACE INTO GL_settings (param, value) VALUES ('expireInterval', '51840');
REPLACE INTO GL_settings (param, value) VALUES ('penaltyInterval', '2');
REPLACE INTO GL_settings (param, value) VALUES ('penaltyEnabled', 'false');
REPLACE INTO GL_settings (param, value) VALUES ('enabled', 'false');

-- Greylisting default server-wide white list
REPLACE INTO GL_remote_domains (domain, `type`) VALUES('*google.com', 'white');
REPLACE INTO GL_remote_domains (domain, `type`) VALUES('*yahoo.com', 'white');
REPLACE INTO GL_remote_domains (domain, `type`) VALUES('*parallels.com', 'white');
REPLACE INTO GL_remote_domains (domain, `type`) VALUES('*mail.ru', 'white');
REPLACE INTO GL_remote_domains (domain, `type`) VALUES('*yandex.ru', 'white');
REPLACE INTO GL_remote_domains (domain, `type`) VALUES('*rambler.ru', 'white');

-- Greylisting default server-wide black list
REPLACE INTO GL_remote_domains (domain, `type`) VALUES('dynamic|static|ppp|dyn-ip|dial-up', 'black');
REPLACE INTO GL_remote_domains (domain, `type`) VALUES('dsl|pool|broadband|hsd', 'black');
REPLACE INTO GL_remote_domains (domain, `type`) VALUES('*[0-9][0-9].[0-9][0-9].[0-9][0-9]*', 'black');
REPLACE INTO GL_remote_domains (domain, `type`) VALUES('*[0-9][0-9][0-9].[0-9][0-9][0-9].[0-9[0-9]][0-9]*', 'black');
REPLACE INTO GL_remote_domains (domain, `type`) VALUES('*[0-9][0-9]-[0-9][0-9]-[0-9][0-9]*', 'black');
REPLACE INTO GL_remote_domains (domain, `type`) VALUES('*[0-9][0-9][0-9]-[0-9][0-9][0-9]-[0-9][0-9][0-9]*', 'black');

-- Spamfilter default settings
REPLACE INTO spamfilter (username, preferences) VALUES ('*@*', 'true');

REPLACE INTO spamfilter_preferences (spamfilter_id, preference, value) SELECT id, 'required_score', '7.00' FROM spamfilter;
REPLACE INTO spamfilter_preferences (spamfilter_id, preference, value) SELECT id, 'rewrite_header', 'subject *****SPAM******' FROM spamfilter;

REPLACE INTO misc (param, val) VALUES('spamfilter_enabled', 'true');
REPLACE INTO misc (param, val) VALUES('spamfilter_use_mailuser_prefs', 'true');

-- Service nodes
REPLACE INTO ServiceNodes (`id`, `name`, `transport`) VALUES (1, 'local', 'local');

-- Number of simultaneously running backups
REPLACE INTO misc (param, val) VALUES('max_bu_proc_number', '10');
